@@ -39,6 +39,7 @@
 #include "common/xfpm-power-common.h"
 #include "common/xfpm-brightness.h"
 #include "common/xfpm-debug.h"
+#include "common/xfpm-enum-glib.h"
 #ifdef XFPM_SYSTRAY
 #include "src/xfpm-inhibit.h"
 #endif
@@ -48,7 +49,6 @@
 
 
 #define SET_LEVEL_TIMEOUT (50)
-#define SAFE_SLIDER_MIN_LEVEL (5)
 
 struct PowerManagerButtonPrivate
 {
@@ -90,21 +90,13 @@ struct PowerManagerButtonPrivate
 
   /* display brightness slider widget */
   GtkWidget       *range;
-  /* Some laptops (and mostly newer ones with intel graphics) can turn off the
-   * backlight completely. If the user is not careful and sets the brightness
-   * very low using the slider, he might not be able to see the screen contents
-   * anymore. Brightness keys do not work on every laptop, so it's better to use
-   * a safe default minimum level that the user can change via the settings
-   * editor if desired.
-   */
-  gint32           brightness_min_level;
+
+  /* filter range value changed events for snappier UI feedback */
+  guint            set_level_timeout;
 
   gint             show_panel_label;
   gboolean         presentation_mode;
   gboolean         show_presentation_indicator;
-
-  /* filter range value changed events for snappier UI feedback */
-  guint            set_level_timeout;
 };
 
 typedef struct
@@ -122,7 +114,6 @@ typedef struct
 typedef enum
 {
   PROP_0 = 0,
-  PROP_BRIGHTNESS_MIN_LEVEL,
   PROP_SHOW_PANEL_LABEL,
   PROP_PRESENTATION_MODE,
   PROP_SHOW_PRESENTATION_INDICATOR,
@@ -160,8 +151,6 @@ static gboolean   power_manager_button_press_event                      (GtkWidg
 static gboolean   power_manager_button_menu_add_device                  (PowerManagerButton *button,
                                                                          BatteryDevice *battery_device,
                                                                          gboolean append);
-static void       increase_brightness                                   (PowerManagerButton *button);
-static void       decrease_brightness                                   (PowerManagerButton *button);
 static void       battery_device_remove_surface                         (BatteryDevice *battery_device);
 
 
@@ -172,8 +161,6 @@ get_display_device (PowerManagerButton *button)
   gdouble highest_percentage = 0;
   BatteryDevice *display_device = NULL;
 
-  TRACE("entering");
-
   g_return_val_if_fail (POWER_MANAGER_IS_BUTTON(button), NULL);
 
   if (button->priv->display_device)
@@ -221,8 +208,6 @@ find_device_in_list (PowerManagerButton *button, const gchar *object_path)
 {
   GList *item = NULL;
 
-  TRACE("entering");
-
   g_return_val_if_fail ( POWER_MANAGER_IS_BUTTON(button), NULL );
 
   for (item = g_list_first (button->priv->devices); item != NULL; item = g_list_next (item))
@@ -230,7 +215,7 @@ find_device_in_list (PowerManagerButton *button, const gchar *object_path)
     BatteryDevice *battery_device = item->data;
     if (battery_device == NULL)
     {
-      DBG("!battery_device");
+      XFPM_DEBUG ("!battery_device");
       continue;
     }
 
@@ -263,8 +248,6 @@ power_manager_button_set_tooltip (PowerManagerButton *button)
 {
   BatteryDevice *display_device = get_display_device (button);
 
-  TRACE("entering");
-
   if (!GTK_IS_WIDGET (button))
   {
     g_critical ("power_manager_button_set_tooltip: !GTK_IS_WIDGET (button)");
@@ -338,11 +321,11 @@ power_manager_button_set_label (PowerManagerButton *button, gdouble percentage,
   }
 
   /* Set the label accordingly or hide it if the battery is full */
-  if (button->priv->show_panel_label == 1)
+  if (button->priv->show_panel_label == PANEL_LABEL_PERCENTAGE)
     label_string = g_strdup_printf ("%d%%", (int) percentage);
-  else if (button->priv->show_panel_label == 2)
+  else if (button->priv->show_panel_label == PANEL_LABEL_TIME)
     label_string = g_strdup_printf ("%s", remaining_time);
-  else if (button->priv->show_panel_label == 3)
+  else if (button->priv->show_panel_label == PANEL_LABEL_PERCENTAGE_AND_TIME)
     label_string = g_strdup_printf ("%d%% - %s", (int) percentage, remaining_time);
 
   gtk_label_set_text (GTK_LABEL (button->priv->panel_label), label_string);
@@ -363,8 +346,6 @@ power_manager_button_device_icon_draw (GtkWidget *img, cairo_t *cr, gpointer use
   PangoRectangle ink_extent, log_extent;
   GtkAllocation allocation;
 
-  TRACE("entering");
-
   /* sanity checks */
   if (!img || !GTK_IS_WIDGET (img))
     return FALSE;
@@ -461,15 +442,13 @@ power_manager_button_update_device_icon_and_details (PowerManagerButton *button,
   BatteryDevice   *battery_device;
   BatteryDevice   *display_device;
   const gchar     *object_path = up_device_get_object_path(device);
-  gchar           *details;
-  gchar           *icon_name;
-  gchar           *menu_icon_name;
+  gchar           *details = NULL;
+  gchar           *icon_name = NULL;
+  gchar           *menu_icon_name = NULL;
   gint             scale_factor;
   GdkPixbuf       *pix;
   cairo_surface_t *surface = NULL;
 
-  XFPM_DEBUG("entering for %s", object_path);
-
   if (!POWER_MANAGER_IS_BUTTON (button))
     return;
 
@@ -480,9 +459,12 @@ power_manager_button_update_device_icon_and_details (PowerManagerButton *button,
 
   battery_device = item->data;
 
-  icon_name = get_device_icon_name (button->priv->upower, device, TRUE);
-  menu_icon_name = get_device_icon_name (button->priv->upower, device, FALSE);
-  details = get_device_description (button->priv->upower, device);
+  if (button->priv->upower != NULL)
+  {
+    icon_name = get_device_icon_name (button->priv->upower, device, TRUE);
+    menu_icon_name = get_device_icon_name (button->priv->upower, device, FALSE);
+    details = get_device_description (button->priv->upower, device);
+  }
 
   /* If UPower doesn't give us an icon, just use the default */
   if (g_strcmp0(menu_icon_name, "") == 0)
@@ -525,7 +507,7 @@ power_manager_button_update_device_icon_and_details (PowerManagerButton *button,
   display_device = get_display_device (button);
   if (battery_device == display_device)
   {
-    DBG("this is the display device, updating");
+    XFPM_DEBUG ("this is the display device, updating");
     /* update the icon */
     g_free (button->priv->panel_icon_name);
 #ifdef XFCE_PLUGIN
@@ -578,8 +560,6 @@ power_manager_button_add_device (UpDevice *device, PowerManagerButton *button)
   const gchar *object_path = up_device_get_object_path(device);
   gulong signal_id;
 
-  XFPM_DEBUG("entering for %s", object_path);
-
   g_return_if_fail (POWER_MANAGER_IS_BUTTON (button ));
 
   /* don't add the same device twice */
@@ -619,8 +599,6 @@ power_manager_button_add_device (UpDevice *device, PowerManagerButton *button)
 static void
 battery_device_remove_surface (BatteryDevice *battery_device)
 {
-  TRACE("entering");
-
   if (battery_device == NULL)
     return;
 
@@ -676,8 +654,6 @@ power_manager_button_remove_device (PowerManagerButton *button, const gchar *obj
   GList *item;
   BatteryDevice *battery_device;
 
-  TRACE("entering for %s", object_path);
-
   item = find_device_in_list (button, object_path);
 
   if (item == NULL)
@@ -711,14 +687,17 @@ power_manager_button_add_all_devices (PowerManagerButton *button)
   GPtrArray *array = NULL;
   guint i;
 
-  button->priv->display_device = up_client_get_display_device (button->priv->upower);
-  power_manager_button_add_device (button->priv->display_device, button);
+  if (button->priv->upower != NULL)
+  {
+    button->priv->display_device = up_client_get_display_device (button->priv->upower);
+    power_manager_button_add_device (button->priv->display_device, button);
 
 #if UP_CHECK_VERSION(0, 99, 8)
-  array = up_client_get_devices2 (button->priv->upower);
+    array = up_client_get_devices2 (button->priv->upower);
 #else
-  array = up_client_get_devices (button->priv->upower);
+    array = up_client_get_devices (button->priv->upower);
 #endif
+  }
 
   if (array)
   {
@@ -737,8 +716,6 @@ power_manager_button_remove_all_devices (PowerManagerButton *button)
 {
   GList *item = NULL;
 
-  TRACE("entering");
-
   g_return_if_fail (POWER_MANAGER_IS_BUTTON (button));
 
   for (item = g_list_first (button->priv->devices); item != NULL; item = g_list_next (item))
@@ -746,7 +723,7 @@ power_manager_button_remove_all_devices (PowerManagerButton *button)
     BatteryDevice *battery_device = item->data;
     if (battery_device == NULL)
     {
-      DBG("!battery_device");
+      XFPM_DEBUG ("!battery_device");
       continue;
     }
 
@@ -758,72 +735,39 @@ power_manager_button_remove_all_devices (PowerManagerButton *button)
 static gboolean
 power_manager_button_scroll_event (GtkWidget *widget, GdkEventScroll *ev)
 {
-  gboolean hw_found;
-  PowerManagerButton *button;
+  PowerManagerButton *button = POWER_MANAGER_BUTTON (widget);
 
-  button = POWER_MANAGER_BUTTON (widget);
-
-  hw_found = xfpm_brightness_has_hw (button->priv->brightness);
-
-  if (!hw_found)
+  if (button->priv->brightness == NULL)
     return FALSE;
 
-  if (ev->direction == GDK_SCROLL_UP)
+  if (ev->direction == GDK_SCROLL_UP || ev->direction == GDK_SCROLL_DOWN)
   {
-    increase_brightness (button);
-    return TRUE;
-  }
-  else if (ev->direction == GDK_SCROLL_DOWN)
-  {
-    decrease_brightness (button);
+    gboolean (*scroll_brightness) (XfpmBrightness *) =
+      ev->direction == GDK_SCROLL_UP ? xfpm_brightness_increase : xfpm_brightness_decrease;
+    if (scroll_brightness (button->priv->brightness) && button->priv->range != NULL)
+    {
+      gint32 level;
+      if (xfpm_brightness_get_level (button->priv->brightness, &level))
+        gtk_range_set_value (GTK_RANGE (button->priv->range), level);
+    }
     return TRUE;
   }
+
   return FALSE;
 }
 
-static void
-set_brightness_min_level (PowerManagerButton *button, gint32 new_brightness_level)
-{
-  gint32 max_level = xfpm_brightness_get_max_level (button->priv->brightness);
-
-  /* sanity check */
-  if (new_brightness_level > max_level)
-    new_brightness_level = -1;
-
-  /* -1 = auto, we set the step value to a hopefully sane default */
-  if (new_brightness_level == -1)
-  {
-    button->priv->brightness_min_level = (max_level > 100) ? SAFE_SLIDER_MIN_LEVEL : 0;
-  }
-  else
-  {
-    button->priv->brightness_min_level = new_brightness_level;
-  }
-
-  DBG("button->priv->brightness_min_level : %d", button->priv->brightness_min_level);
-
-  /* update the range if it's being shown */
-  if (button->priv->range)
-  {
-    gtk_range_set_range (GTK_RANGE (button->priv->range), button->priv->brightness_min_level, max_level);
-  }
-}
-
 static void
 power_manager_button_set_property (GObject *object,
                                    guint property_id,
                                    const GValue *value,
                                    GParamSpec *pspec)
 {
-  PowerManagerButton *button;
-
-  button = POWER_MANAGER_BUTTON (object);
+#ifdef XFCE_PLUGIN
+  PowerManagerButton *button = POWER_MANAGER_BUTTON (object);
+#endif
 
   switch (property_id)
   {
-    case PROP_BRIGHTNESS_MIN_LEVEL:
-      set_brightness_min_level (button, g_value_get_int (value));
-      break;
 #ifdef XFCE_PLUGIN
     case PROP_SHOW_PANEL_LABEL:
       button->priv->show_panel_label = g_value_get_int (value);
@@ -839,6 +783,11 @@ power_manager_button_set_property (GObject *object,
       if (GTK_IS_WIDGET (button->priv->panel_presentation_mode))
           power_manager_button_update_presentation_indicator (button);
       break;
+#else
+    case PROP_SHOW_PANEL_LABEL:
+    case PROP_PRESENTATION_MODE:
+    case PROP_SHOW_PRESENTATION_INDICATOR:
+      break;
 #endif
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -852,15 +801,12 @@ power_manager_button_get_property(GObject *object,
                                   GValue *value,
                                   GParamSpec *pspec)
 {
-  PowerManagerButton *button;
-
-  button = POWER_MANAGER_BUTTON (object);
+#ifdef XFCE_PLUGIN
+  PowerManagerButton *button = POWER_MANAGER_BUTTON (object);
+#endif
 
   switch(property_id)
   {
-    case PROP_BRIGHTNESS_MIN_LEVEL:
-      g_value_set_int (value, button->priv->brightness_min_level);
-      break;
 #ifdef XFCE_PLUGIN
     case PROP_SHOW_PANEL_LABEL:
       g_value_set_int (value, button->priv->show_panel_label);
@@ -871,6 +817,11 @@ power_manager_button_get_property(GObject *object,
     case PROP_SHOW_PRESENTATION_INDICATOR:
       g_value_set_boolean (value, button->priv->show_presentation_indicator);
       break;
+#else
+    case PROP_SHOW_PANEL_LABEL:
+    case PROP_PRESENTATION_MODE:
+    case PROP_SHOW_PRESENTATION_INDICATOR:
+      break;
 #endif
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -878,6 +829,22 @@ power_manager_button_get_property(GObject *object,
   }
 }
 
+static void
+set_brightness_properties (PowerManagerButton *button)
+{
+  gint32 level = xfconf_channel_get_int (button->priv->channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_SLIDER_MIN_LEVEL, -1);
+  guint step_count = xfconf_channel_get_uint (button->priv->channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_STEP_COUNT, 10);
+  gboolean exponential = xfconf_channel_get_bool (button->priv->channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_EXPONENTIAL, FALSE);
+
+  /* order accounts: default min level depends on step count */
+  xfpm_brightness_set_step_count (button->priv->brightness, step_count, exponential);
+  xfpm_brightness_set_min_level (button->priv->brightness, level);
+  if (button->priv->range != NULL)
+    gtk_range_set_range (GTK_RANGE (button->priv->range),
+                         xfpm_brightness_get_min_level (button->priv->brightness),
+                         xfpm_brightness_get_max_level (button->priv->brightness));
+}
+
 static void
 power_manager_button_class_init (PowerManagerButtonClass *klass)
 {
@@ -915,19 +882,10 @@ power_manager_button_class_init (PowerManagerButtonClass *klass)
                            | G_PARAM_STATIC_NICK \
                            | G_PARAM_STATIC_BLURB)
 
-  /* We allow and default to -1 only so that we can automagically set a
-   * sane value if the user hasn't selected one already */
-  g_object_class_install_property (object_class, PROP_BRIGHTNESS_MIN_LEVEL,
-                                   g_param_spec_int(BRIGHTNESS_SLIDER_MIN_LEVEL,
-                                                    BRIGHTNESS_SLIDER_MIN_LEVEL,
-                                                    BRIGHTNESS_SLIDER_MIN_LEVEL,
-                                                    -1, G_MAXINT32, -1,
-                                                    XFPM_PARAM_FLAGS));
-
   g_object_class_install_property (object_class, PROP_SHOW_PANEL_LABEL,
                                    g_param_spec_int (SHOW_PANEL_LABEL,
                                                      NULL, NULL,
-                                                     0, G_MAXINT16, 3,
+                                                     PANEL_LABEL_NONE, PANEL_LABEL_PERCENTAGE_AND_TIME, PANEL_LABEL_PERCENTAGE,
                                                      XFPM_PARAM_FLAGS));
 
   g_object_class_install_property (object_class, PROP_PRESENTATION_MODE,
@@ -977,7 +935,6 @@ power_manager_button_init (PowerManagerButton *button)
   gtk_widget_set_name (GTK_WIDGET (button), "xfce4-power-manager-plugin");
 
   button->priv->brightness = xfpm_brightness_new ();
-  xfpm_brightness_setup (button->priv->brightness);
   button->priv->set_level_timeout = 0;
 
   button->priv->upower  = up_client_new ();
@@ -992,6 +949,14 @@ power_manager_button_init (PowerManagerButton *button)
   else
   {
     button->priv->channel = xfconf_channel_get (XFPM_CHANNEL);
+    if (button->priv->brightness != NULL)
+    {
+      set_brightness_properties (button);
+      g_signal_connect_object (button->priv->channel, "property-changed::" XFPM_PROPERTIES_PREFIX BRIGHTNESS_SLIDER_MIN_LEVEL,
+                               G_CALLBACK (set_brightness_properties), button, G_CONNECT_SWAPPED);
+      g_signal_connect_object (button->priv->channel, "property-changed::" XFPM_PROPERTIES_PREFIX BRIGHTNESS_STEP_COUNT,
+                               G_CALLBACK (set_brightness_properties), button, G_CONNECT_SWAPPED);
+    }
   }
 
 #ifdef XFCE_PLUGIN
@@ -1030,8 +995,11 @@ power_manager_button_init (PowerManagerButton *button)
   /* Intercept scroll events */
   gtk_widget_add_events (GTK_WIDGET (button), GDK_SCROLL_MASK);
 
-  g_signal_connect (button->priv->upower, "device-added", G_CALLBACK (device_added_cb), button);
-  g_signal_connect (button->priv->upower, "device-removed", G_CALLBACK (device_removed_cb), button);
+  if (button->priv->upower != NULL)
+  {
+    g_signal_connect (button->priv->upower, "device-added", G_CALLBACK (device_added_cb), button);
+    g_signal_connect (button->priv->upower, "device-removed", G_CALLBACK (device_removed_cb), button);
+  }
 }
 
 static void
@@ -1039,25 +1007,34 @@ power_manager_button_finalize (GObject *object)
 {
   PowerManagerButton *button;
 
-  DBG("entering");
-
   button = POWER_MANAGER_BUTTON (object);
 
   g_free (button->priv->panel_icon_name);
   g_free (button->priv->panel_fallback_icon_name);
 
+  if (button->priv->brightness != NULL)
+    g_object_unref (button->priv->brightness);
   if (button->priv->set_level_timeout)
   {
     g_source_remove(button->priv->set_level_timeout);
     button->priv->set_level_timeout = 0;
   }
 
-  g_signal_handlers_disconnect_by_data (button->priv->upower, button);
+  if (button->priv->upower != NULL)
+  {
+    g_signal_handlers_disconnect_by_data (button->priv->upower, button);
+    g_object_unref (button->priv->upower);
+  }
 
   power_manager_button_remove_all_devices (button);
+  g_list_free (button->priv->devices);
 
 #ifdef XFCE_PLUGIN
   g_object_unref (button->priv->plugin);
+  if (button->priv->inhibit_proxy != NULL)
+    g_object_unref (button->priv->inhibit_proxy);
+#else
+  g_object_unref (button->priv->inhibit);
 #endif
 
   if (button->priv->channel != NULL)
@@ -1079,17 +1056,14 @@ power_manager_button_new (void)
 
 #ifdef XFCE_PLUGIN
   button->priv->plugin = XFCE_PANEL_PLUGIN (g_object_ref (plugin));
-#endif
-
-  xfconf_g_property_bind (button->priv->channel,
-                          XFPM_PROPERTIES_PREFIX BRIGHTNESS_SLIDER_MIN_LEVEL, G_TYPE_INT,
-                          G_OBJECT (button), BRIGHTNESS_SLIDER_MIN_LEVEL);
   xfconf_g_property_bind (button->priv->channel, XFPM_PROPERTIES_PREFIX SHOW_PANEL_LABEL, G_TYPE_INT,
                           G_OBJECT (button), SHOW_PANEL_LABEL);
   xfconf_g_property_bind (button->priv->channel, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE, G_TYPE_BOOLEAN,
                           G_OBJECT (button), PRESENTATION_MODE);
   xfconf_g_property_bind (button->priv->channel, XFPM_PROPERTIES_PREFIX SHOW_PRESENTATION_INDICATOR, G_TYPE_BOOLEAN,
                           G_OBJECT (button), SHOW_PRESENTATION_INDICATOR);
+#endif
+
   return GTK_WIDGET (button);
 }
 
@@ -1271,7 +1245,7 @@ power_manager_button_update_label (PowerManagerButton *button, UpDevice *device)
       return;
 
 #ifdef XFCE_PLUGIN
-  if (button->priv->show_panel_label <= 0 || button->priv->show_panel_label >3)
+  if (button->priv->show_panel_label == PANEL_LABEL_NONE)
   {
     gtk_widget_hide (GTK_WIDGET (button->priv->panel_label));
     power_manager_button_size_changed_cb (button->priv->plugin,
@@ -1309,8 +1283,6 @@ menu_destroyed_cb(GtkMenuShell *menu, gpointer user_data)
 {
   PowerManagerButton *button = POWER_MANAGER_BUTTON (user_data);
 
-  TRACE("entering");
-
   /* menu destroyed, range slider is gone */
   button->priv->range = NULL;
 
@@ -1379,7 +1351,7 @@ power_manager_button_menu_add_device (PowerManagerButton *button, BatteryDevice
     /* Don't add the display device or line power to the menu */
     if (type == UP_DEVICE_KIND_LINE_POWER || battery_device->device == button->priv->display_device)
     {
-      DBG("filtering device from menu (display or line power device)");
+      XFPM_DEBUG ("filtering device from menu (display or line power device)");
       return FALSE;
     }
   }
@@ -1528,51 +1500,11 @@ display_inhibitors (PowerManagerButton *button, GtkWidget *menu)
 }
 #endif
 
-static void
-decrease_brightness (PowerManagerButton *button)
-{
-  gint32 level, next_level;
-
-
-  TRACE("entering");
-
-  if ( !xfpm_brightness_has_hw (button->priv->brightness) )
-    return;
-
-  xfpm_brightness_get_level (button->priv->brightness, &level);
-  next_level = MAX (button->priv->brightness_min_level,
-                    xfpm_brightness_dec (button->priv->brightness, level));
-
-  xfpm_brightness_set_level(button->priv->brightness, next_level);
-  if (button->priv->range)
-    gtk_range_set_value (GTK_RANGE (button->priv->range), next_level);
-}
-
-static void
-increase_brightness (PowerManagerButton *button)
-{
-  gint32 level, next_level;
-
-  TRACE("entering");
-
-  if (!xfpm_brightness_has_hw (button->priv->brightness))
-    return;
-
-  xfpm_brightness_get_level (button->priv->brightness, &level);
-  next_level = xfpm_brightness_inc (button->priv->brightness, level);
-
-  xfpm_brightness_set_level (button->priv->brightness, next_level);
-  if (button->priv->range)
-      gtk_range_set_value (GTK_RANGE (button->priv->range), next_level);
-}
-
 static gboolean
 brightness_set_level_with_timeout (PowerManagerButton *button)
 {
   gint32 range_level, hw_level;
 
-  TRACE("entering");
-
   range_level = (gint32) gtk_range_get_value (GTK_RANGE (button->priv->range));
 
   xfpm_brightness_get_level (button->priv->brightness, &hw_level);
@@ -1594,8 +1526,6 @@ brightness_set_level_with_timeout (PowerManagerButton *button)
 static void
 range_value_changed_cb (PowerManagerButton *button, GtkWidget *widget)
 {
-  TRACE("entering");
-
   if (button->priv->set_level_timeout)
     return;
 
@@ -1604,28 +1534,12 @@ range_value_changed_cb (PowerManagerButton *button, GtkWidget *widget)
                    (GSourceFunc) brightness_set_level_with_timeout, button);
 }
 
-static void
-range_scroll_cb (GtkWidget *widget, GdkEvent *event, PowerManagerButton *button)
-{
-  GdkEventScroll *scroll_event;
-
-  TRACE("entering");
-
-  scroll_event = (GdkEventScroll*)event;
-
-  if (scroll_event->direction == GDK_SCROLL_UP)
-    increase_brightness (button);
-  else if (scroll_event->direction == GDK_SCROLL_DOWN)
-    decrease_brightness (button);
-}
-
 static void
 range_show_cb (GtkWidget *widget, PowerManagerButton *button)
 {
   GdkSeat   *seat = gdk_display_get_default_seat (gdk_display_get_default());
   GdkDevice *pointer = gdk_seat_get_pointer (seat);
 
-  TRACE("entering");
   /* Release these grabs as they will cause a lockup if pkexec is called
    * for the brightness helper */
   if (pointer)
@@ -1650,16 +1564,13 @@ power_manager_button_toggle_presentation_mode (GtkMenuItem *mi, GtkSwitch *sw)
 void
 power_manager_button_show_menu (PowerManagerButton *button)
 {
-  GtkWidget *menu, *mi, *img = NULL;
+  GtkWidget *menu, *mi;
 #ifdef XFCE_PLUGIN
   GtkWidget *box, *label, *sw;
 #endif
   GdkScreen *gscreen;
   GList *item;
   gboolean show_separator_flag = FALSE;
-  gint32 max_level, current_level = 0;
-
-  TRACE("entering");
 
   g_return_if_fail (POWER_MANAGER_IS_BUTTON (button));
 
@@ -1695,27 +1606,14 @@ power_manager_button_show_menu (PowerManagerButton *button)
   }
 
   /* Display brightness slider - show if there's hardware support for it */
-  if ( xfpm_brightness_has_hw (button->priv->brightness) )
+  if (button->priv->brightness != NULL)
   {
-    guint brightness_step_count;
-    gboolean brightness_exponential;
+    GtkWidget *img;
+    gint32 current_level = 0;
 
-    max_level = xfpm_brightness_get_max_level (button->priv->brightness);
-
-    /* Setup brightness steps */
-    brightness_step_count =
-      xfconf_channel_get_uint (button->priv->channel,
-                               XFPM_PROPERTIES_PREFIX BRIGHTNESS_STEP_COUNT,
-                               10);
-    brightness_exponential =
-      xfconf_channel_get_bool (button->priv->channel,
-                               XFPM_PROPERTIES_PREFIX BRIGHTNESS_EXPONENTIAL,
-                               FALSE);
-    xfpm_brightness_set_step_count (button->priv->brightness,
-                                    brightness_step_count,
-                                    brightness_exponential);
-
-    mi = scale_menu_item_new_with_range (button->priv->brightness_min_level, max_level, 1);
+    mi = scale_menu_item_new_with_range (xfpm_brightness_get_min_level (button->priv->brightness),
+                                         xfpm_brightness_get_max_level (button->priv->brightness),
+                                         1);
 
     scale_menu_item_set_description_label (SCALE_MENU_ITEM (mi), _("<b>Display brightness</b>"));
 
@@ -1727,7 +1625,7 @@ power_manager_button_show_menu (PowerManagerButton *button)
     gtk_range_set_value (GTK_RANGE (button->priv->range), current_level);
 
     g_signal_connect_swapped (mi, "value-changed", G_CALLBACK (range_value_changed_cb), button);
-    g_signal_connect (mi, "scroll-event", G_CALLBACK (range_scroll_cb), button);
+    g_signal_connect_swapped (mi, "scroll-event", G_CALLBACK (power_manager_button_scroll_event), button);
     g_signal_connect (menu, "show", G_CALLBACK (range_show_cb), button);
 
     /* load and display the brightness icon and force it to 32px size */
