@@ -27,8 +27,13 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_X11
+#include <gdk/gdkx.h>
+#define WINDOWING_IS_X11() GDK_IS_X11_DISPLAY (gdk_display_get_default ())
+#else
+#define WINDOWING_IS_X11() FALSE
+#endif
 #include <gtk/gtk.h>
-#include <glib.h>
 #include <cairo-gobject.h>
 #include <upower.h>
 
@@ -42,6 +47,7 @@
 #include "xfpm-debug.h"
 #include "xfpm-power-common.h"
 #include "xfpm-power.h"
+#include "xfpm-ppd-common.h"
 #include "xfpm-backlight.h"
 
 #include "interfaces/xfpm-settings_ui.h"
@@ -57,10 +63,8 @@ static  GtkApplication *app     = NULL;
 static  GtkBuilder *xml       = NULL;
 static  GtkWidget  *nt        = NULL;
 
-static  GtkWidget *on_battery_display_blank = NULL;
 static  GtkWidget *on_battery_dpms_sleep  = NULL;
 static  GtkWidget *on_battery_dpms_off    = NULL;
-static  GtkWidget *on_ac_display_blank    = NULL;
 static  GtkWidget *on_ac_dpms_sleep     = NULL;
 static  GtkWidget *on_ac_dpms_off     = NULL;
 static  GtkWidget *sideview                 = NULL; /* Sidebar tree view - all devices are in the sideview */
@@ -70,8 +74,6 @@ static  GtkWidget *brightness_exponential   = NULL;
 
 static  GtkWidget *label_inactivity_on_ac                       = NULL;
 static  GtkWidget *label_inactivity_on_battery                  = NULL;
-static  GtkWidget *label_display_blank_on_battery               = NULL;
-static  GtkWidget *label_display_blank_on_ac                    = NULL;
 static  GtkWidget *label_dpms_sleep_on_battery                  = NULL;
 static  GtkWidget *label_dpms_sleep_on_ac                       = NULL;
 static  GtkWidget *label_dpms_off_on_battery                    = NULL;
@@ -144,12 +146,8 @@ gboolean    dpms_toggled_cb                            (GtkWidget *w,
                                                         XfconfChannel *channel);
 void        sleep_on_battery_value_changed_cb          (GtkWidget *w,
                                                         XfconfChannel *channel);
-void        display_blank_on_battery_value_changed_cb  (GtkWidget *w,
-                                                        XfconfChannel *channel);
 void        off_on_battery_value_changed_cb            (GtkWidget *w,
                                                         XfconfChannel *channel);
-void        display_blank_on_ac_value_changed_cb       (GtkWidget *w,
-                                                        XfconfChannel *channel);
 void        sleep_on_ac_value_changed_cb               (GtkWidget *w,
                                                         XfconfChannel *channel);
 void        off_on_ac_value_changed_cb                 (GtkWidget *w,
@@ -176,6 +174,10 @@ void        on_ac_sleep_mode_changed_cb                (GtkWidget *w,
                                                         XfconfChannel *channel);
 void        on_battery_sleep_mode_changed_cb           (GtkWidget *w,
                                                         XfconfChannel *channel);
+void        on_ac_power_profile_changed_cb             (GtkWidget *w,
+                                                        XfconfChannel *channel);
+void        on_battery_power_profile_changed_cb        (GtkWidget *w,
+                                                        XfconfChannel *channel);
 gboolean    handle_brightness_keys_toggled_cb          (GtkWidget *w,
                                                         gboolean is_active,
                                                         XfconfChannel *channel);
@@ -420,6 +422,59 @@ on_battery_sleep_mode_changed_cb (GtkWidget *w, XfconfChannel *channel)
   }
 }
 
+void
+on_ac_power_profile_changed_cb (GtkWidget *w, XfconfChannel *channel)
+{
+  GtkTreeModel *model;
+  GtkTreeIter selected_row;
+  gchar *profile = NULL;
+
+  if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (w), &selected_row))
+    return;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (w));
+
+  gtk_tree_model_get(model,
+                     &selected_row,
+                     0,
+                     &profile,
+                     -1);
+
+  if (!xfconf_channel_set_string (channel, XFPM_PROPERTIES_PREFIX PROFILE_ON_AC, profile))
+  {
+    g_critical ("Cannot set value for property %s\n", PROFILE_ON_AC);
+  }
+
+  g_free (profile);
+}
+
+void
+on_battery_power_profile_changed_cb (GtkWidget *w, XfconfChannel *channel)
+{
+  GtkTreeModel *model;
+  GtkTreeIter selected_row;
+  gchar *profile = NULL;
+
+  if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (w), &selected_row))
+    return;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (w));
+
+  gtk_tree_model_get(model,
+                     &selected_row,
+                     0,
+                     &profile,
+                     -1);
+
+  if (!xfconf_channel_set_string (channel, XFPM_PROPERTIES_PREFIX PROFILE_ON_BATTERY, profile))
+  {
+    g_critical ("Cannot set value for property %s\n", PROFILE_ON_BATTERY);
+  }
+
+  g_free (profile);
+}
+
+
 gboolean
 dpms_toggled_cb (GtkWidget *w, gboolean is_active, XfconfChannel *channel)
 {
@@ -439,43 +494,12 @@ dpms_toggled_cb (GtkWidget *w, gboolean is_active, XfconfChannel *channel)
   return FALSE;
 }
 
-void
-display_blank_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
-{
-  GtkWidget *brg;
-  gint blank_value = (gint) gtk_range_get_value (GTK_RANGE (on_battery_display_blank));
-  gint sleep_value = (gint) gtk_range_get_value (GTK_RANGE (on_battery_dpms_sleep));
-  gint brightness_value;
-
-  if ( sleep_value != 0 )
-  {
-    if ( blank_value >= sleep_value )
-    {
-      gtk_range_set_value (GTK_RANGE(on_battery_dpms_sleep), blank_value + 1 );
-    }
-  }
-
-  if ( lcd_brightness )
-  {
-    brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-battery"));
-    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
-
-    if ( blank_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
-    {
-      gtk_range_set_value (GTK_RANGE (brg), 0);
-    }
-  }
-
-  update_label (label_display_blank_on_battery, w, format_dpms_value_cb);
-}
-
 void
 sleep_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
 {
   GtkWidget *brg;
   gint off_value    = (gint) gtk_range_get_value (GTK_RANGE (on_battery_dpms_off));
   gint sleep_value  = (gint) gtk_range_get_value (GTK_RANGE (w));
-  gint blank_value  = (gint) gtk_range_get_value (GTK_RANGE (on_battery_display_blank));
   gint brightness_value;
 
   if ( off_value != 0 )
@@ -486,14 +510,6 @@ sleep_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
     }
   }
 
-  if ( blank_value != 0 )
-  {
-    if ( blank_value >= sleep_value )
-    {
-      gtk_range_set_value (GTK_RANGE(on_battery_display_blank), sleep_value - 1 );
-    }
-  }
-
   if ( lcd_brightness )
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-battery"));
@@ -535,36 +551,6 @@ off_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   update_label (label_dpms_off_on_battery, w, format_dpms_value_cb);
 }
 
-void
-display_blank_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
-{
-  GtkWidget *brg;
-  gint blank_value = (gint) gtk_range_get_value (GTK_RANGE (on_ac_display_blank));
-  gint sleep_value = (gint) gtk_range_get_value (GTK_RANGE (on_ac_dpms_sleep));
-  gint brightness_value;
-
-  if ( sleep_value != 0 )
-  {
-    if ( blank_value >= sleep_value )
-    {
-      gtk_range_set_value (GTK_RANGE(on_ac_dpms_sleep), blank_value + 1 );
-    }
-  }
-
-  if ( lcd_brightness )
-  {
-    brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-ac"));
-    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
-
-    if ( blank_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
-    {
-      gtk_range_set_value (GTK_RANGE (brg), 0);
-    }
-  }
-
-  update_label (label_display_blank_on_ac, w, format_dpms_value_cb);
-}
-
 void
 sleep_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
 {
@@ -573,7 +559,6 @@ sleep_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   gint brightness_value;
   gint off_value    = (gint)gtk_range_get_value (GTK_RANGE (on_ac_dpms_off));
   gint sleep_value  = (gint)gtk_range_get_value (GTK_RANGE (w));
-  gint blank_value  = (gint)gtk_range_get_value (GTK_RANGE (on_ac_display_blank));
 
   if ( off_value > 60 || sleep_value > 60 )
     return;
@@ -586,14 +571,6 @@ sleep_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
     }
   }
 
-  if ( blank_value != 0 )
-  {
-    if ( blank_value >= sleep_value )
-    {
-      gtk_range_set_value (GTK_RANGE(on_ac_display_blank), sleep_value - 1 );
-    }
-  }
-
   if ( lcd_brightness )
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-ac"));
@@ -778,7 +755,13 @@ on_battery_lid_changed_cb (GtkWidget *w, XfconfChannel *channel)
   {
     g_critical ("Cannot set value for property %s\n", LID_SWITCH_ON_BATTERY_CFG);
   }
-  xfpm_update_logind_handle_lid_switch (channel);
+
+  /* Light Locker Integration */
+  if ( light_locker_settings )
+  {
+    xfpm_update_logind_handle_lid_switch (channel);
+  }
+  /* END Light Locker Integration */
 }
 
 void
@@ -803,7 +786,13 @@ on_ac_lid_changed_cb (GtkWidget *w, XfconfChannel *channel)
   {
     g_critical ("Cannot set value for property %s\n", LID_SWITCH_ON_AC_CFG);
   }
-  xfpm_update_logind_handle_lid_switch (channel);
+
+  /* Light Locker Integration */
+  if ( light_locker_settings )
+  {
+    xfpm_update_logind_handle_lid_switch (channel);
+  }
+  /* END Light Locker Integration */
 }
 
 void
@@ -886,10 +875,11 @@ xfpm_update_logind_handle_lid_switch (XfconfChannel *channel)
 /* END Light Locker Integration */
 
 static void
-xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
-                          gboolean auth_hibernate, gboolean can_suspend,
-                          gboolean can_hibernate, gboolean can_shutdown,
-                          gboolean has_lcd_brightness, gboolean has_lid)
+xfpm_settings_on_battery (XfconfChannel *channel, GDBusProxy *profiles_proxy,
+                          gboolean auth_suspend, gboolean auth_hibernate,
+                          gboolean can_suspend, gboolean can_hibernate,
+                          gboolean can_shutdown, gboolean has_lcd_brightness,
+                          gboolean has_lid)
 {
   gboolean valid, handle_dpms;
   gint list_value;
@@ -901,6 +891,8 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
   GtkWidget *lid;
   GtkWidget *brg;
   GtkWidget *brg_level;
+  GtkWidget *power_profile;
+  GSList *profiles;
 
   /*
    * Inactivity sleep mode on battery
@@ -1092,6 +1084,55 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
     gtk_widget_hide (lid);
   }
 
+  /*
+   * Power profile on battery
+   */
+  power_profile = GTK_WIDGET (gtk_builder_get_object (xml, "power-profile-on-battery"));
+  if (profiles_proxy != NULL && (profiles = xfpm_ppd_get_profiles (profiles_proxy)) != NULL)
+  {
+    gchar *enabled_profile;
+
+    list_store = gtk_list_store_new (1, G_TYPE_STRING);
+    gtk_combo_box_set_model (GTK_COMBO_BOX (power_profile), GTK_TREE_MODEL (list_store));
+
+    for (GSList *l = profiles; l != NULL; l = l->next)
+    {
+      gchar *profile = l->data;
+
+      gtk_list_store_append (list_store, &iter);
+      gtk_list_store_set (list_store, &iter, 0, profile, -1);
+    }
+
+    enabled_profile = xfconf_channel_get_string (channel, XFPM_PROPERTIES_PREFIX PROFILE_ON_BATTERY, "balanced");
+
+    for (valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store), &iter);
+         valid;
+         valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter))
+    {
+      gchar *profile_value;
+
+      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
+                          0, &profile_value, -1);
+      if (g_strcmp0 (profile_value, enabled_profile) == 0)
+      {
+        gtk_combo_box_set_active_iter (GTK_COMBO_BOX (power_profile), &iter);
+        break;
+      }
+
+      g_free (profile_value);
+    }
+
+    g_free (enabled_profile);
+    g_slist_free_full (profiles, g_free);
+  }
+  else
+  {
+    gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (xml, "power-profile-label-on-battery")));
+    gtk_widget_hide (power_profile);
+  }
+
+
+
   /*
    * Brightness on battery
    */
@@ -1112,14 +1153,12 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
   }
 
   label_inactivity_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "system-sleep-inactivity-on-battery-label"));
-  label_display_blank_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "display-blank-on-battery-label"));
   label_dpms_sleep_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-on-battery-label"));
   label_dpms_off_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-off-on-battery-label"));
   label_brightness_level_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-on-battery-label"));
   label_brightness_inactivity_on_battery = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-battery-label"));
 
   update_label (label_inactivity_on_battery, inact_timeout, format_inactivity_value_cb);
-  update_label (label_display_blank_on_battery, on_battery_display_blank, format_dpms_value_cb);
   update_label (label_dpms_sleep_on_battery, on_battery_dpms_sleep, format_dpms_value_cb);
   update_label (label_dpms_off_on_battery, on_battery_dpms_off, format_dpms_value_cb);
   update_label (label_brightness_level_on_battery, brg_level, format_brightness_percentage_cb);
@@ -1127,20 +1166,22 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
 }
 
 static void
-xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
-                     gboolean auth_hibernate, gboolean can_suspend,
-                     gboolean can_hibernate, gboolean has_lcd_brightness,
-                     gboolean has_lid)
+xfpm_settings_on_ac (XfconfChannel *channel, GDBusProxy *profiles_proxy,
+                     gboolean auth_suspend, gboolean auth_hibernate,
+                     gboolean can_suspend, gboolean can_hibernate,
+                     gboolean has_lcd_brightness, gboolean has_lid)
 {
   gboolean valid, handle_dpms;
   GtkWidget *inact_timeout, *inact_action;
   GtkWidget *lid;
   GtkWidget *brg;
   GtkWidget *brg_level;
+  GtkWidget *power_profile;
   GtkListStore *list_store;
   GtkTreeIter iter;
   guint val;
   guint list_value;
+  GSList *profiles;
 
   /*
    * Inactivity sleep mode on AC
@@ -1282,6 +1323,53 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
     gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (xml, "lid-plugged-in-header")));
   }
 
+  /*
+   * Power profile on AC power
+   */
+  power_profile = GTK_WIDGET (gtk_builder_get_object (xml, "power-profile-on-ac"));
+  if (profiles_proxy != NULL && (profiles = xfpm_ppd_get_profiles (profiles_proxy)) != NULL)
+  {
+    gchar *enabled_profile;
+
+    list_store = gtk_list_store_new (1, G_TYPE_STRING);
+    gtk_combo_box_set_model (GTK_COMBO_BOX (power_profile), GTK_TREE_MODEL (list_store));
+
+    for (GSList *l = profiles; l != NULL; l = l->next)
+    {
+      gchar *profile = l->data;
+
+      gtk_list_store_append (list_store, &iter);
+      gtk_list_store_set (list_store, &iter, 0, profile, -1);
+    }
+
+    enabled_profile = xfconf_channel_get_string (channel, XFPM_PROPERTIES_PREFIX PROFILE_ON_AC, "balanced");
+
+    for (valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store), &iter);
+         valid;
+         valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter))
+    {
+      gchar *profile_value;
+
+      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
+                          0, &profile_value, -1);
+      if (g_strcmp0 (profile_value, enabled_profile) == 0)
+      {
+        gtk_combo_box_set_active_iter (GTK_COMBO_BOX (power_profile), &iter);
+        break;
+      }
+
+      g_free (profile_value);
+    }
+
+    g_free (enabled_profile);
+    g_slist_free_full (profiles, g_free);
+  }
+  else
+  {
+    gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (xml, "power-profile-label-on-ac")));
+    gtk_widget_hide (power_profile);
+  }
+
   /*
    * Brightness on AC power
    */
@@ -1302,14 +1390,12 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
   }
 
   label_inactivity_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "system-sleep-inactivity-on-ac-label"));
-  label_display_blank_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "display-blank-on-ac-label"));
   label_dpms_sleep_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-on-ac-label"));
   label_dpms_off_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-off-on-ac-label"));
   label_brightness_level_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-on-ac-label"));
   label_brightness_inactivity_on_ac = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-ac-label"));
 
   update_label (label_inactivity_on_ac, inact_timeout, format_inactivity_value_cb);
-  update_label (label_display_blank_on_ac, on_ac_display_blank, format_dpms_value_cb);
   update_label (label_dpms_sleep_on_ac, on_ac_dpms_sleep, format_dpms_value_cb);
   update_label (label_dpms_off_on_ac, on_ac_dpms_off, format_dpms_value_cb);
   update_label (label_brightness_level_on_ac, brg_level, format_brightness_percentage_cb);
@@ -1926,7 +2012,7 @@ update_device_info_value_for_name (GtkTreeView *view,
   g_return_if_fail (name != NULL);
   /* Value can be NULL */
 
-  DBG ("updating  name %s with value %s", name, value);
+  XFPM_DEBUG ("updating  name %s with value %s", name, value);
 
   iter = find_device_info_name_in_tree (view, name);
   if (iter == NULL)
@@ -1967,8 +2053,6 @@ update_sideview_icon (UpDevice *device,
 
   list_store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (sideview)));
 
-  TRACE("entering for %s", object_path);
-
   iter = find_device_in_tree (object_path);
 
   /* quit if device doesn't exist in the sidebar */
@@ -1983,8 +2067,11 @@ update_sideview_icon (UpDevice *device,
                 NULL);
 
 
-  name = get_device_description (upower, device);
-  icon_name = get_device_icon_name (upower, device, FALSE);
+  if (upower != NULL)
+  {
+    name = get_device_description (upower, device);
+    icon_name = get_device_icon_name (upower, device, FALSE);
+  }
 
   pix = gtk_icon_theme_load_icon_for_scale (gtk_icon_theme_get_default (),
                                             icon_name,
@@ -2023,14 +2110,12 @@ update_device_details (UpDevice *device)
   GtkTreeIter *sideview_iter;
   gchar *str;
   guint type = 0, tech = 0;
-  gdouble energy_full_design = -1.0, energy_full = -1.0, energy_empty = -1.0, voltage = -1.0, percent = -1.0;
+  gdouble energy_full_design = -1.0, energy_full = -1.0, energy_empty = -1.0, energy_rate = -1.0, voltage = -1.0, percent = -1.0;
   gboolean p_supply = FALSE;
   gchar *model = NULL, *vendor = NULL, *serial = NULL;
   const gchar *battery_type = NULL;
   const gchar *object_path = up_device_get_object_path(device);
 
-  TRACE("entering for %s", object_path);
-
   sideview_iter = find_device_in_tree (object_path);
 
   /* quit if device doesn't exist in the sidebar */
@@ -2064,6 +2149,7 @@ update_device_details (UpDevice *device)
                 "energy-full-design", &energy_full_design,
                 "energy-full", &energy_full,
                 "energy-empty", &energy_empty,
+                "energy-rate", &energy_rate,
                 "voltage", &voltage,
                 "percentage", &percent,
                 NULL);
@@ -2133,6 +2219,16 @@ update_device_details (UpDevice *device)
       g_free (str);
     }
 
+    if (energy_rate > 0)
+    {
+      /* TRANSLATORS: Unit here is Watt*/
+      str = xfpm_info_get_energy_property (energy_rate, _("W"));
+
+      update_device_info_value_for_name (view, list_store, _("Energy rate"), str);
+
+      g_free (str);
+    }
+
     if (voltage > 0)
     {
       /* TRANSLATORS: Unit here is Volt*/
@@ -2177,8 +2273,6 @@ add_device (UpDevice *device)
   guint index;
   static gboolean first_run = TRUE;
 
-  TRACE("entering for %s", object_path);
-
   /* don't add the same device twice */
   device_iter = find_device_in_tree (object_path);
   if (device_iter)
@@ -2263,8 +2357,6 @@ remove_device (const gchar *object_path)
   gulong signal_id;
   UpDevice *device;
 
-  TRACE("entering for %s", object_path);
-
   iter = find_device_in_tree (object_path);
 
   if (iter == NULL)
@@ -2331,10 +2423,12 @@ settings_create_devices_list (void)
 {
   upower = up_client_new ();
 
-  g_signal_connect (upower, "device-added", G_CALLBACK (device_added_cb), NULL);
-  g_signal_connect (upower, "device-removed", G_CALLBACK (device_removed_cb), NULL);
-
-  add_all_devices ();
+  if (upower != NULL)
+  {
+    g_signal_connect (upower, "device-added", G_CALLBACK (device_added_cb), NULL);
+    g_signal_connect (upower, "device-removed", G_CALLBACK (device_removed_cb), NULL);
+    add_all_devices ();
+  }
 }
 
 static void
@@ -2365,6 +2459,9 @@ settings_quit (GtkWidget *widget, XfconfChannel *channel)
   g_object_unref (channel);
   xfconf_shutdown ();
   gtk_widget_destroy (widget);
+  if (upower != NULL)
+    g_object_unref (upower);
+
   /* initiate the quit action on the application so it terminates */
   g_action_group_activate_action (G_ACTION_GROUP(app), "quit", NULL);
 }
@@ -2382,11 +2479,13 @@ static void dialog_response_cb (GtkDialog *dialog, gint response, XfconfChannel
   }
 }
 
+#ifdef ENABLE_X11
 static void
 delete_event_cb (GtkWidget *plug, GdkEvent *ev, XfconfChannel *channel)
 {
   settings_quit (plug, channel);
 }
+#endif
 
 GtkWidget *
 xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
@@ -2395,16 +2494,16 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
                           gboolean has_battery, gboolean has_lcd_brightness,
                           gboolean has_lid, gboolean has_sleep_button,
                           gboolean has_hibernate_button, gboolean has_power_button,
-                          gboolean has_battery_button,  Window id, gchar *device_id,
+                          gboolean has_battery_button,
+#ifdef ENABLE_X11
+                          Window id,
+#endif
+                          gchar *device_id,
                           GtkApplication *gtk_app)
 {
-  GtkWidget *plug;
-  GtkWidget *parent;
   GtkWidget *dialog;
-  GtkWidget *plugged_box;
   GtkWidget *viewport;
   GtkWidget *hbox;
-  GtkWidget *frame;
   GtkWidget *switch_widget;
   GtkWidget *stack;
   GtkStyleContext *context;
@@ -2412,8 +2511,8 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
   GtkTreeViewColumn *col;
   GtkCellRenderer *renderer;
   GError *error = NULL;
-  guint val;
   GtkCssProvider *css_provider;
+  GDBusProxy *profiles_proxy = xfpm_ppd_g_dbus_proxy_new ();
 
   XFPM_DEBUG ("auth_hibernate=%s auth_suspend=%s can_shutdown=%s can_suspend=%s can_hibernate=%s " \
               "has_battery=%s has_lcd_brightness=%s has_lid=%s has_sleep_button=%s " \
@@ -2441,18 +2540,6 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
   on_ac_dpms_sleep = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-on-ac"));
   on_ac_dpms_off = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-off-on-ac"));
 
-  on_battery_display_blank = GTK_WIDGET (gtk_builder_get_object (xml, "display-blank-on-battery"));
-  val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX ON_BATTERY_BLANK, 1);
-  gtk_range_set_value (GTK_RANGE (on_battery_display_blank), val);
-  xfconf_g_property_bind (channel, XFPM_PROPERTIES_PREFIX ON_BATTERY_BLANK,
-                          G_TYPE_INT, gtk_range_get_adjustment (GTK_RANGE (on_battery_display_blank)),
-                          "value");
-
-  on_ac_display_blank = GTK_WIDGET (gtk_builder_get_object (xml, "display-blank-on-ac"));
-  xfconf_g_property_bind (channel, XFPM_PROPERTIES_PREFIX ON_AC_BLANK,
-                          G_TYPE_INT, gtk_range_get_adjustment (GTK_RANGE (on_ac_display_blank)),
-                          "value");
-
   switch_widget = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
   xfconf_g_property_bind (channel, XFPM_PROPERTIES_PREFIX HANDLE_BRIGHTNESS_KEYS,
                           G_TYPE_BOOLEAN, switch_widget, "active");
@@ -2532,6 +2619,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
   settings_create_devices_list ();
 
   xfpm_settings_on_ac (channel,
+                       profiles_proxy,
                        auth_suspend,
                        auth_hibernate,
                        can_suspend,
@@ -2539,8 +2627,9 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
                        has_lcd_brightness,
                        has_lid);
 
-  if ( has_battery )
+  if (has_battery)
   xfpm_settings_on_battery (channel,
+                            profiles_proxy,
                             auth_suspend,
                             auth_hibernate,
                             can_suspend,
@@ -2570,25 +2659,60 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
 
   if ( !has_lcd_brightness )
   {
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-frame"));
-    gtk_widget_hide (frame);
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
-    gtk_widget_hide (frame);
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys-label"));
-    gtk_widget_hide (frame);
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-step-count"));
-    gtk_widget_hide (frame);
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-exponential"));
-    gtk_widget_hide (frame);
+    GtkWidget *widget = GTK_WIDGET (gtk_builder_get_object (xml, "label4"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-label"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-label"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-vbox"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-vbox"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "label6"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-label1"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-label1"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-vbox1"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-vbox1"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys-label"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "hbox4"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-step-count-label"));
+    gtk_widget_hide (widget);
   }
 
-  if ( id != 0 )
+  if (!WINDOWING_IS_X11 ())
   {
-    plugged_box = GTK_WIDGET (gtk_builder_get_object (xml, "plug-child"));
-    plug = gtk_plug_new (id);
-    gtk_widget_show (plug);
+    GtkWidget *widget = GTK_WIDGET (gtk_builder_get_object (xml, "buttons-frame"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "hbox21"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-label"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-box"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-label1"));
+    gtk_widget_hide (widget);
+    widget = GTK_WIDGET (gtk_builder_get_object (xml, "dpms-sleep-box1"));
+    gtk_widget_hide (widget);
+  }
 
-    parent = gtk_widget_get_parent (plugged_box);
+#ifdef ENABLE_X11
+  if (id != 0 && WINDOWING_IS_X11 ())
+  {
+    GtkWidget *plugged_box = GTK_WIDGET (gtk_builder_get_object (xml, "plug-child"));
+    GtkWidget *parent = gtk_widget_get_parent (plugged_box);
+    GtkWidget *plug = gtk_plug_new (id);
+
+    gtk_widget_show (plug);
     if (parent)
     {
       g_object_ref (plugged_box);
@@ -2602,6 +2726,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
     gdk_notify_startup_complete ();
   }
   else
+#endif
   {
     g_signal_connect (dialog, "response", G_CALLBACK (dialog_response_cb), channel);
     gtk_widget_show (dialog);
@@ -2620,6 +2745,9 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
    * quit message */
   app = gtk_app;
 
+  if (profiles_proxy != NULL)
+    g_object_unref (profiles_proxy);
+
   return dialog;
 }
 
@@ -2634,14 +2762,14 @@ xfpm_settings_show_device_id (gchar *device_id)
   gtk_widget_show (gtk_notebook_get_nth_page (GTK_NOTEBOOK (nt), devices_page_num));
   gtk_notebook_set_current_page (GTK_NOTEBOOK (nt), devices_page_num);
 
-  DBG("device_id %s", device_id);
+  XFPM_DEBUG ("device_id %s", device_id);
 
   device_iter = find_device_in_tree (device_id);
   if (device_iter)
   {
     GtkTreeSelection *selection;
 
-    DBG("device found");
+    XFPM_DEBUG ("device found");
 
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (sideview));
 
