@@ -38,7 +38,7 @@
 #include <libxfce4util/libxfce4util.h>
 
 #include "xfpm-backlight.h"
-#include "egg-idletime.h"
+#include "xfpm-idle.h"
 #include "xfpm-notify.h"
 #include "xfpm-xfconf.h"
 #include "xfpm-power.h"
@@ -67,14 +67,13 @@ struct XfpmBacklightPrivate
 {
   XfpmBrightness *brightness;
   XfpmPower      *power;
-  EggIdletime    *idle;
+  XfpmIdle       *idle;
   XfpmXfconf     *conf;
   XfpmButton     *button;
   XfpmNotify     *notify;
 
   NotifyNotification *n;
 
-  gboolean      has_hw;
   gboolean      on_battery;
 
   gint32          last_level;
@@ -119,7 +118,7 @@ xfpm_backlight_dim_brightness (XfpmBacklight *backlight)
 
     if ( !ret )
     {
-      g_warning ("Unable to get current brightness level");
+      XFPM_DEBUG ("Unable to get current brightness level");
       return;
     }
 
@@ -198,18 +197,18 @@ xfpm_backlight_show (XfpmBacklight *backlight, gint level)
 
 
 static void
-xfpm_backlight_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmBacklight *backlight)
+xfpm_backlight_alarm_timeout_cb (XfpmIdle *idle, XfpmAlarmId id, XfpmBacklight *backlight)
 {
   backlight->priv->block = FALSE;
 
-  if ( id == TIMEOUT_BRIGHTNESS_ON_AC && !backlight->priv->on_battery)
+  if (id == XFPM_ALARM_ID_BRIGHTNESS_ON_AC && !backlight->priv->on_battery)
     xfpm_backlight_dim_brightness (backlight);
-  else if ( id == TIMEOUT_BRIGHTNESS_ON_BATTERY && backlight->priv->on_battery)
+  else if (id == XFPM_ALARM_ID_BRIGHTNESS_ON_BATTERY && backlight->priv->on_battery)
     xfpm_backlight_dim_brightness (backlight);
 }
 
 static void
-xfpm_backlight_reset_cb (EggIdletime *idle, XfpmBacklight *backlight)
+xfpm_backlight_reset_cb (XfpmIdle *idle, XfpmBacklight *backlight)
 {
   if ( backlight->priv->dimmed)
   {
@@ -258,9 +257,6 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
 
   backlight->priv->block = TRUE;
 
-  /* get the current brightness level */
-  ret = xfpm_brightness_get_level (backlight->priv->brightness, &level);
-
   /* optionally, handle updating the level and setting the screen brightness */
   if ( handle_brightness_keys )
   {
@@ -269,16 +265,17 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
                                     brightness_exponential);
     if ( type == BUTTON_MON_BRIGHTNESS_UP )
     {
-      level = xfpm_brightness_inc (backlight->priv->brightness, level);
+      xfpm_brightness_increase (backlight->priv->brightness);
     }
     else
     {
-      level = xfpm_brightness_dec (backlight->priv->brightness, level);
+      xfpm_brightness_decrease (backlight->priv->brightness);
     }
-
-    ret = xfpm_brightness_set_level (backlight->priv->brightness, level);
   }
 
+  /* get the current brightness level */
+  ret = xfpm_brightness_get_level (backlight->priv->brightness, &level);
+
   /* optionally, show the result in a popup (even if it did not change) */
   if ( ret && show_popup )
     xfpm_backlight_show (backlight, level);
@@ -297,11 +294,11 @@ xfpm_backlight_brightness_on_ac_settings_changed (XfpmBacklight *backlight)
 
   if ( timeout_on_ac == ALARM_DISABLED )
   {
-    egg_idletime_alarm_remove (backlight->priv->idle, TIMEOUT_BRIGHTNESS_ON_AC );
+    xfpm_idle_alarm_remove (backlight->priv->idle, XFPM_ALARM_ID_BRIGHTNESS_ON_AC);
   }
   else
   {
-    egg_idletime_alarm_set (backlight->priv->idle, TIMEOUT_BRIGHTNESS_ON_AC, timeout_on_ac * 1000);
+    xfpm_idle_alarm_add (backlight->priv->idle, XFPM_ALARM_ID_BRIGHTNESS_ON_AC, timeout_on_ac * 1000);
   }
 }
 
@@ -318,22 +315,15 @@ xfpm_backlight_brightness_on_battery_settings_changed (XfpmBacklight *backlight)
 
   if ( timeout_on_battery == ALARM_DISABLED )
   {
-    egg_idletime_alarm_remove (backlight->priv->idle, TIMEOUT_BRIGHTNESS_ON_BATTERY );
+    xfpm_idle_alarm_remove (backlight->priv->idle, XFPM_ALARM_ID_BRIGHTNESS_ON_BATTERY);
   }
   else
   {
-    egg_idletime_alarm_set (backlight->priv->idle, TIMEOUT_BRIGHTNESS_ON_BATTERY, timeout_on_battery * 1000);
+    xfpm_idle_alarm_add (backlight->priv->idle, XFPM_ALARM_ID_BRIGHTNESS_ON_BATTERY, timeout_on_battery * 1000);
   }
 }
 
 
-static void
-xfpm_backlight_set_timeouts (XfpmBacklight *backlight)
-{
-  xfpm_backlight_brightness_on_ac_settings_changed (backlight);
-  xfpm_backlight_brightness_on_battery_settings_changed (backlight);
-}
-
 static void
 xfpm_backlight_on_battery_changed_cb (XfpmPower *power, gboolean on_battery, XfpmBacklight *backlight)
 {
@@ -374,7 +364,6 @@ xfpm_backlight_init (XfpmBacklight *backlight)
   backlight->priv = xfpm_backlight_get_instance_private (backlight);
 
   backlight->priv->brightness = xfpm_brightness_new ();
-  backlight->priv->has_hw     = xfpm_brightness_setup (backlight->priv->brightness);
 
   backlight->priv->notify = NULL;
   backlight->priv->idle   = NULL;
@@ -387,16 +376,11 @@ xfpm_backlight_init (XfpmBacklight *backlight)
   backlight->priv->brightness_exponential = FALSE;
   backlight->priv->brightness_switch_initialized = FALSE;
 
-  if ( !backlight->priv->has_hw )
+  if (backlight->priv->brightness != NULL)
   {
-    g_object_unref (backlight->priv->brightness);
-    backlight->priv->brightness = NULL;
-  }
-  else
-  {
-    gboolean ret, handle_keys;
+    gboolean handle_keys;
 
-    backlight->priv->idle   = egg_idletime_new ();
+    backlight->priv->idle   = xfpm_idle_new ();
     backlight->priv->conf   = xfpm_xfconf_new ();
     backlight->priv->button = xfpm_button_new ();
     backlight->priv->power    = xfpm_power_get ();
@@ -408,14 +392,7 @@ xfpm_backlight_init (XfpmBacklight *backlight)
                             XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH, G_TYPE_INT,
                             G_OBJECT (backlight), BRIGHTNESS_SWITCH);
 
-    ret = xfpm_brightness_get_switch (backlight->priv->brightness,
-                      &backlight->priv->brightness_switch);
-
-    if (ret)
-      g_object_set (G_OBJECT (backlight),
-                    BRIGHTNESS_SWITCH,
-                    backlight->priv->brightness_switch,
-                    NULL);
+    xfpm_brightness_get_switch (backlight->priv->brightness, &backlight->priv->brightness_switch);
     backlight->priv->brightness_switch_initialized = TRUE;
 
     /*
@@ -440,9 +417,9 @@ xfpm_backlight_init (XfpmBacklight *backlight)
     }
     else
     {
-      g_warning ("It seems the kernel brightness switch handling value was "
-                 "not restored properly on exit last time, xfce4-power-manager "
-                 "will try to restore it this time.");
+      XFPM_DEBUG ("It seems the kernel brightness switch handling value was "
+                  "not restored properly on exit last time, xfce4-power-manager "
+                  "will try to restore it this time.");
     }
 
       /* check whether to change the brightness switch */
@@ -455,24 +432,28 @@ xfpm_backlight_init (XfpmBacklight *backlight)
             backlight->priv->brightness_switch,
             NULL);
 
-    g_signal_connect (backlight->priv->idle, "alarm-expired",
-                      G_CALLBACK (xfpm_backlight_alarm_timeout_cb), backlight);
-    g_signal_connect (backlight->priv->idle, "reset",
-                      G_CALLBACK(xfpm_backlight_reset_cb), backlight);
-    g_signal_connect (backlight->priv->button, "button-pressed",
-                      G_CALLBACK (xfpm_backlight_button_pressed_cb), backlight);
-    g_signal_connect_swapped (backlight->priv->conf, "notify::" BRIGHTNESS_ON_AC,
-                              G_CALLBACK (xfpm_backlight_brightness_on_ac_settings_changed), backlight);
-    g_signal_connect_swapped (backlight->priv->conf, "notify::" BRIGHTNESS_ON_BATTERY,
-                              G_CALLBACK (xfpm_backlight_brightness_on_battery_settings_changed), backlight);
-    g_signal_connect (backlight->priv->power, "on-battery-changed",
-                      G_CALLBACK (xfpm_backlight_on_battery_changed_cb), backlight);
+    if (backlight->priv->idle != NULL)
+    {
+      g_signal_connect_object (backlight->priv->idle, "alarm-expired",
+                               G_CALLBACK (xfpm_backlight_alarm_timeout_cb), backlight, 0);
+      g_signal_connect_object (backlight->priv->idle, "reset",
+                               G_CALLBACK(xfpm_backlight_reset_cb), backlight, 0);
+      g_signal_connect_object (backlight->priv->conf, "notify::" BRIGHTNESS_ON_AC,
+                               G_CALLBACK (xfpm_backlight_brightness_on_ac_settings_changed), backlight, G_CONNECT_SWAPPED);
+      g_signal_connect_object (backlight->priv->conf, "notify::" BRIGHTNESS_ON_BATTERY,
+                               G_CALLBACK (xfpm_backlight_brightness_on_battery_settings_changed), backlight, G_CONNECT_SWAPPED);
+      xfpm_backlight_brightness_on_ac_settings_changed (backlight);
+      xfpm_backlight_brightness_on_battery_settings_changed (backlight);
+    }
+    g_signal_connect_object (backlight->priv->button, "button-pressed",
+                             G_CALLBACK (xfpm_backlight_button_pressed_cb), backlight, 0);
+    g_signal_connect_object (backlight->priv->power, "on-battery-changed",
+                             G_CALLBACK (xfpm_backlight_on_battery_changed_cb), backlight, 0);
 
     g_object_get (G_OBJECT (backlight->priv->power),
                   "on-battery", &backlight->priv->on_battery,
                   NULL);
     xfpm_brightness_get_level (backlight->priv->brightness, &backlight->priv->last_level);
-    xfpm_backlight_set_timeouts (backlight);
 
     /* setup step count */
     backlight->priv->brightness_step_count =
@@ -526,11 +507,11 @@ xfpm_backlight_set_property (GObject *object,
       ret = xfpm_brightness_set_switch (backlight->priv->brightness,
                                         backlight->priv->brightness_switch);
       if (!ret)
-          g_warning ("Unable to set the kernel brightness switch parameter to %d.",
-                     backlight->priv->brightness_switch);
+          XFPM_DEBUG ("Unable to set the kernel brightness switch parameter to %d.",
+                      backlight->priv->brightness_switch);
       else
-          g_message ("Set kernel brightness switch to %d",
-                     backlight->priv->brightness_switch);
+          XFPM_DEBUG ("Set kernel brightness switch to %d",
+                      backlight->priv->brightness_switch);
 
       break;
     case PROP_BRIGHTNESS_SWITCH_SAVE:
@@ -570,11 +551,11 @@ xfpm_backlight_finalize (GObject *object)
     if (ret)
     {
       backlight->priv->brightness_switch = backlight->priv->brightness_switch_save;
-      g_message ("Restored brightness switch value to: %d", backlight->priv->brightness_switch);
+      XFPM_DEBUG ("Restored brightness switch value to: %d", backlight->priv->brightness_switch);
     }
     else
-      g_warning ("Unable to restore the kernel brightness switch parameter to its original value, "
-                 "still resetting the saved value.");
+      XFPM_DEBUG ("Unable to restore the kernel brightness switch parameter to its original value, "
+                  "still resetting the saved value.");
     }
     g_object_unref (backlight->priv->conf);
   }
@@ -597,12 +578,12 @@ xfpm_backlight_finalize (GObject *object)
 XfpmBacklight *
 xfpm_backlight_new (void)
 {
-  XfpmBacklight *backlight = NULL;
-  backlight = g_object_new (XFPM_TYPE_BACKLIGHT, NULL);
+  XfpmBacklight *backlight = g_object_new (XFPM_TYPE_BACKLIGHT, NULL);
+  if (backlight->priv->brightness == NULL)
+  {
+    g_object_unref (backlight);
+    return NULL;
+  }
+
   return backlight;
 }
-
-gboolean xfpm_backlight_has_hw (XfpmBacklight *backlight)
-{
-  return backlight->priv->has_hw;
-}
