@@ -37,14 +37,13 @@
 #include <string.h>
 #endif
 
+#ifdef ENABLE_X11
 #include <X11/X.h>
 #include <X11/XF86keysym.h>
-
 #include <gdk/gdkx.h>
+#endif
 #include <gtk/gtk.h>
 
-#include <glib.h>
-
 #include <libxfce4util/libxfce4util.h>
 
 #include "xfpm-button.h"
@@ -54,17 +53,18 @@
 
 static void xfpm_button_finalize   (GObject *object);
 
+#ifdef ENABLE_X11
 static struct
 {
   XfpmButtonKey    key;
   guint            key_code;
 } xfpm_key_map [NUMBER_OF_BUTTONS] = { {0, 0}, };
+#endif
 
 struct XfpmButtonPrivate
 {
   GdkScreen   *screen;
   GdkWindow   *window;
-  gboolean     handle_brightness_keys;
   guint16      mapped_buttons;
 };
 
@@ -80,6 +80,8 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (XfpmButton, xfpm_button, G_TYPE_OBJECT)
 
+#ifdef ENABLE_X11
+
 static guint
 xfpm_button_get_key (unsigned int keycode)
 {
@@ -183,39 +185,6 @@ xfpm_button_xevent_key (XfpmButton *button, guint keysym , XfpmButtonKey key)
   return TRUE;
 }
 
-static void
-xfpm_button_ungrab (XfpmButton *button, guint keysym, XfpmButtonKey key)
-{
-  Display *display;
-  GdkDisplay *gdisplay;
-  guint modmask = AnyModifier;
-  guint keycode = XKeysymToKeycode (gdk_x11_get_default_xdisplay(), keysym);
-
-  if (keycode == 0)
-  {
-    XFPM_DEBUG ("could not map keysym %x to keycode\n", keysym);
-    return;
-  }
-
-  display = gdk_x11_get_default_xdisplay ();
-  gdisplay = gdk_display_get_default ();
-
-  gdk_x11_display_error_trap_push (gdisplay);
-
-  XUngrabKey (display, keycode, modmask,
-              GDK_WINDOW_XID (button->priv->window));
-  XUngrabKey (display, keycode, LockMask | modmask,
-              GDK_WINDOW_XID (button->priv->window));
-
-  gdk_display_flush (gdisplay);
-  gdk_x11_display_error_trap_pop_ignored (gdisplay);
-
-  XFPM_DEBUG_ENUM (key, XFPM_TYPE_BUTTON_KEY, "Ungrabbed key %li ", (long int) keycode);
-
-  xfpm_key_map [key].key_code = 0;
-  xfpm_key_map [key].key = 0;
-}
-
 static void
 xfpm_button_setup (XfpmButton *button)
 {
@@ -238,14 +207,11 @@ xfpm_button_setup (XfpmButton *button)
   if ( xfpm_button_xevent_key (button, XF86XK_Sleep, BUTTON_SLEEP) )
     button->priv->mapped_buttons |= SLEEP_KEY;
 
-  if (button->priv->handle_brightness_keys)
-  {
-    if ( xfpm_button_xevent_key (button, XF86XK_MonBrightnessUp, BUTTON_MON_BRIGHTNESS_UP) )
-      button->priv->mapped_buttons |= BRIGHTNESS_KEY_UP;
+  if ( xfpm_button_xevent_key (button, XF86XK_MonBrightnessUp, BUTTON_MON_BRIGHTNESS_UP) )
+    button->priv->mapped_buttons |= BRIGHTNESS_KEY_UP;
 
-    if (xfpm_button_xevent_key (button, XF86XK_MonBrightnessDown, BUTTON_MON_BRIGHTNESS_DOWN) )
-      button->priv->mapped_buttons |= BRIGHTNESS_KEY_DOWN;
-  }
+  if (xfpm_button_xevent_key (button, XF86XK_MonBrightnessDown, BUTTON_MON_BRIGHTNESS_DOWN) )
+    button->priv->mapped_buttons |= BRIGHTNESS_KEY_DOWN;
 
   if (xfpm_button_xevent_key (button, XF86XK_Battery, BUTTON_BATTERY))
     button->priv->mapped_buttons |= BATTERY_KEY;
@@ -259,6 +225,8 @@ xfpm_button_setup (XfpmButton *button)
   gdk_window_add_filter (button->priv->window, xfpm_button_filter_x_events, button);
 }
 
+#endif /* ENABLE_X11 */
+
 static void
 xfpm_button_class_init(XfpmButtonClass *klass)
 {
@@ -281,12 +249,14 @@ xfpm_button_init (XfpmButton *button)
 {
   button->priv = xfpm_button_get_instance_private (button);
 
-  button->priv->handle_brightness_keys = FALSE;
   button->priv->mapped_buttons = 0;
   button->priv->screen = NULL;
   button->priv->window = NULL;
 
-  xfpm_button_setup (button);
+#ifdef ENABLE_X11
+  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+    xfpm_button_setup (button);
+#endif
 }
 
 static void
@@ -320,38 +290,3 @@ xfpm_button_get_mapped (XfpmButton *button)
 
   return button->priv->mapped_buttons;
 }
-
-void
-xfpm_button_set_handle_brightness_keys (XfpmButton *button,
-                                        gboolean handle_brightness_keys)
-{
-  g_return_if_fail (XFPM_IS_BUTTON (button));
-
-  if (button->priv->handle_brightness_keys != handle_brightness_keys)
-  {
-    button->priv->handle_brightness_keys = handle_brightness_keys;
-
-    if (handle_brightness_keys)
-    {
-      if (xfpm_button_xevent_key (button, XF86XK_MonBrightnessUp, BUTTON_MON_BRIGHTNESS_UP))
-        button->priv->mapped_buttons |= BRIGHTNESS_KEY_UP;
-
-      if (xfpm_button_xevent_key (button, XF86XK_MonBrightnessDown, BUTTON_MON_BRIGHTNESS_DOWN))
-        button->priv->mapped_buttons |= BRIGHTNESS_KEY_DOWN;
-    }
-    else
-    {
-      if ((button->priv->mapped_buttons & BRIGHTNESS_KEY_UP) != 0)
-      {
-        xfpm_button_ungrab (button, XF86XK_MonBrightnessUp, BUTTON_MON_BRIGHTNESS_UP);
-        button->priv->mapped_buttons &= ~(BRIGHTNESS_KEY_UP);
-      }
-
-      if ((button->priv->mapped_buttons & BRIGHTNESS_KEY_DOWN) != 0)
-      {
-        xfpm_button_ungrab (button, XF86XK_MonBrightnessDown, BUTTON_MON_BRIGHTNESS_DOWN);
-        button->priv->mapped_buttons &= ~(BRIGHTNESS_KEY_DOWN);
-      }
-    }
-  }
-}
