@@ -31,8 +31,13 @@
 #include <string.h>
 #endif
 
+#ifdef ENABLE_X11
+#include <gdk/gdkx.h>
+#define WINDOWING_IS_X11() GDK_IS_X11_DISPLAY (gdk_display_get_default ())
+#else
+#define WINDOWING_IS_X11() FALSE
+#endif
 #include <gtk/gtk.h>
-#include <glib.h>
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -50,7 +55,7 @@
 #include "xfpm-backlight.h"
 #include "xfpm-kbd-backlight.h"
 #include "xfpm-inhibit.h"
-#include "egg-idletime.h"
+#include "xfpm-idle.h"
 #include "xfpm-config.h"
 #include "xfpm-debug.h"
 #include "xfpm-xfconf.h"
@@ -60,6 +65,7 @@
 #include "xfpm-enum-glib.h"
 #include "xfpm-enum-types.h"
 #include "xfpm-dbus-monitor.h"
+#include "xfpm-ppd.h"
 #include "../panel-plugins/power-manager-plugin/power-manager-button.h"
 
 static void xfpm_manager_finalize   (GObject *object);
@@ -87,7 +93,10 @@ struct XfpmManagerPrivate
   GDBusConnection    *session_bus;
   GDBusConnection    *system_bus;
 
+#ifdef ENABLE_X11
   XfceSMClient       *client;
+  gboolean            session_managed;
+#endif
 
   XfpmPower          *power;
   XfpmButton         *button;
@@ -98,8 +107,9 @@ struct XfpmManagerPrivate
   XfceSystemd        *systemd;
   XfpmDBusMonitor    *monitor;
   XfpmInhibit        *inhibit;
+  XfpmPPD            *ppd;
   XfceScreensaver    *screensaver;
-  EggIdletime        *idle;
+  XfpmIdle           *idle;
   GtkStatusIcon      *adapter_icon;
   GtkWidget          *power_button;
   gint                show_tray_icon;
@@ -109,7 +119,6 @@ struct XfpmManagerPrivate
   GTimer         *timer;
 
   gboolean          inhibited;
-  gboolean          session_managed;
 
   gint                inhibit_fd;
 };
@@ -172,20 +181,27 @@ xfpm_manager_finalize (GObject *object)
   g_object_unref (manager->priv->power);
   g_object_unref (manager->priv->button);
   g_object_unref (manager->priv->conf);
-  g_object_unref (manager->priv->client);
+#ifdef ENABLE_X11
+  if (manager->priv->client != NULL)
+    g_object_unref (manager->priv->client);
+#endif
   if ( manager->priv->systemd != NULL )
     g_object_unref (manager->priv->systemd);
   if ( manager->priv->console != NULL )
     g_object_unref (manager->priv->console);
   g_object_unref (manager->priv->monitor);
   g_object_unref (manager->priv->inhibit);
-  g_object_unref (manager->priv->idle);
+  g_object_unref (manager->priv->ppd);
+  if (manager->priv->idle != NULL)
+    g_object_unref (manager->priv->idle);
 
   g_timer_destroy (manager->priv->timer);
 
-  g_object_unref (manager->priv->dpms);
+  if (manager->priv->dpms != NULL)
+    g_object_unref (manager->priv->dpms);
 
-  g_object_unref (manager->priv->backlight);
+  if (manager->priv->backlight != NULL)
+    g_object_unref (manager->priv->backlight);
 
   g_object_unref (manager->priv->kbd_backlight);
 
@@ -209,11 +225,13 @@ xfpm_manager_set_property (GObject *object,
         manager->priv->show_tray_icon = new_value;
         if (new_value > 0)
         {
-          xfpm_manager_show_tray_icon (manager);
+          if (WINDOWING_IS_X11 ())
+            xfpm_manager_show_tray_icon (manager);
         }
         else
         {
-          xfpm_manager_hide_tray_icon (manager);
+          if (WINDOWING_IS_X11 ())
+            xfpm_manager_hide_tray_icon (manager);
         }
       }
       break;
@@ -311,16 +329,20 @@ xfpm_manager_shutdown (XfpmManager *manager)
     g_warning ("Failed to shutdown the system : %s", error->message);
     g_error_free (error);
     /* Try with the session then */
+#ifdef ENABLE_X11
     if ( manager->priv->session_managed )
       xfce_sm_client_request_shutdown (manager->priv->client, XFCE_SM_CLIENT_SHUTDOWN_HINT_HALT);
+#endif
   }
 }
 
 static void
 xfpm_manager_ask_shutdown (XfpmManager *manager)
 {
+#ifdef ENABLE_X11
   if ( manager->priv->session_managed )
-  xfce_sm_client_request_shutdown (manager->priv->client, XFCE_SM_CLIENT_SHUTDOWN_HINT_ASK);
+    xfce_sm_client_request_shutdown (manager->priv->client, XFCE_SM_CLIENT_SHUTDOWN_HINT_ASK);
+#endif
 }
 
 static void
@@ -440,8 +462,8 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
 
     if ( action == LID_TRIGGER_DPMS )
     {
-      if ( !xfpm_is_multihead_connected () )
-        xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOff);
+      if (manager->priv->dpms != NULL && !xfpm_is_multihead_connected ())
+        xfpm_dpms_set_mode (manager->priv->dpms, XFPM_DPMS_MODE_OFF);
     }
     else if ( action == LID_TRIGGER_LOCK_SCREEN )
     {
@@ -470,8 +492,8 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
   {
     XFPM_DEBUG_ENUM (action, XFPM_TYPE_LID_TRIGGER_ACTION, "LID opened");
 
-    if ( action != LID_TRIGGER_NOTHING )
-      xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOn);
+    if (manager->priv->dpms != NULL && action != LID_TRIGGER_NOTHING)
+      xfpm_dpms_set_mode (manager->priv->dpms, XFPM_DPMS_MODE_ON);
   }
 }
 
@@ -482,14 +504,14 @@ xfpm_manager_inhibit_changed_cb (XfpmInhibit *inhibit, gboolean inhibited, XfpmM
 }
 
 static void
-xfpm_manager_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmManager *manager)
+xfpm_manager_alarm_timeout_cb (XfpmIdle *idle, XfpmAlarmId id, XfpmManager *manager)
 {
   if (xfpm_power_is_in_presentation_mode (manager->priv->power) == TRUE)
     return;
 
   XFPM_DEBUG ("Alarm inactivity timeout id %d", id);
 
-  if ( id == TIMEOUT_INACTIVITY_ON_AC || id == TIMEOUT_INACTIVITY_ON_BATTERY )
+  if (id == XFPM_ALARM_ID_INACTIVITY_ON_AC || id == XFPM_ALARM_ID_INACTIVITY_ON_BATTERY)
   {
     XfpmShutdownRequest sleep_mode = XFPM_DO_NOTHING;
     gboolean on_battery;
@@ -500,7 +522,7 @@ xfpm_manager_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmManager *manager
       return;
     }
 
-    if ( id == TIMEOUT_INACTIVITY_ON_AC)
+    if (id == XFPM_ALARM_ID_INACTIVITY_ON_AC)
       g_object_get (G_OBJECT (manager->priv->conf),
                     INACTIVITY_SLEEP_MODE_ON_AC, &sleep_mode,
                     NULL);
@@ -513,9 +535,8 @@ xfpm_manager_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmManager *manager
                   "on-battery", &on_battery,
                   NULL);
 
-    if ( id == TIMEOUT_INACTIVITY_ON_AC && on_battery == FALSE )
-      xfpm_manager_sleep_request (manager, sleep_mode, FALSE);
-    else if ( id ==  TIMEOUT_INACTIVITY_ON_BATTERY && on_battery )
+    if ((id == XFPM_ALARM_ID_INACTIVITY_ON_AC && !on_battery)
+        || (id ==  XFPM_ALARM_ID_INACTIVITY_ON_BATTERY && on_battery))
       xfpm_manager_sleep_request (manager, sleep_mode, FALSE);
   }
 }
@@ -529,20 +550,18 @@ xfpm_manager_set_idle_alarm_on_ac (XfpmManager *manager)
                 ON_AC_INACTIVITY_TIMEOUT, &on_ac,
                 NULL);
 
-#ifdef DEBUG
   if ( on_ac == 14 )
-    TRACE ("setting inactivity sleep timeout on ac to never");
+    XFPM_DEBUG ("setting inactivity sleep timeout on ac to never");
   else
-    TRACE ("setting inactivity sleep timeout on ac to %d", on_ac);
-#endif
+    XFPM_DEBUG ("setting inactivity sleep timeout on ac to %d", on_ac);
 
   if ( on_ac == 14 )
   {
-    egg_idletime_alarm_remove (manager->priv->idle, TIMEOUT_INACTIVITY_ON_AC );
+    xfpm_idle_alarm_remove (manager->priv->idle, XFPM_ALARM_ID_INACTIVITY_ON_AC);
   }
   else
   {
-    egg_idletime_alarm_set (manager->priv->idle, TIMEOUT_INACTIVITY_ON_AC, on_ac * 1000 * 60);
+    xfpm_idle_alarm_add (manager->priv->idle, XFPM_ALARM_ID_INACTIVITY_ON_AC, on_ac * 1000 * 60);
   }
 }
 
@@ -555,34 +574,25 @@ xfpm_manager_set_idle_alarm_on_battery (XfpmManager *manager)
                 ON_BATTERY_INACTIVITY_TIMEOUT, &on_battery,
                 NULL);
 
-#ifdef DEBUG
   if ( on_battery == 14 )
-    TRACE ("setting inactivity sleep timeout on battery to never");
+    XFPM_DEBUG ("setting inactivity sleep timeout on battery to never");
   else
-    TRACE ("setting inactivity sleep timeout on battery to %d", on_battery);
-#endif
+    XFPM_DEBUG ("setting inactivity sleep timeout on battery to %d", on_battery);
 
   if ( on_battery == 14 )
   {
-    egg_idletime_alarm_remove (manager->priv->idle, TIMEOUT_INACTIVITY_ON_BATTERY );
+    xfpm_idle_alarm_remove (manager->priv->idle, XFPM_ALARM_ID_INACTIVITY_ON_BATTERY);
   }
   else
   {
-    egg_idletime_alarm_set (manager->priv->idle, TIMEOUT_INACTIVITY_ON_BATTERY, on_battery * 1000 * 60);
+    xfpm_idle_alarm_add (manager->priv->idle, XFPM_ALARM_ID_INACTIVITY_ON_BATTERY, on_battery * 1000 * 60);
   }
 }
 
 static void
 xfpm_manager_on_battery_changed_cb (XfpmPower *power, gboolean on_battery, XfpmManager *manager)
 {
-  egg_idletime_alarm_reset_all (manager->priv->idle);
-}
-
-static void
-xfpm_manager_set_idle_alarm (XfpmManager *manager)
-{
-  xfpm_manager_set_idle_alarm_on_ac (manager);
-  xfpm_manager_set_idle_alarm_on_battery (manager);
+  xfpm_idle_alarm_reset_all (manager->priv->idle);
 }
 
 static gchar*
@@ -752,7 +762,7 @@ xfpm_manager_show_tray_icon (XfpmManager *manager)
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   manager->priv->adapter_icon = gtk_status_icon_new ();
-  manager->priv->power_button = power_manager_button_new ();
+  manager->priv->power_button = g_object_ref_sink (power_manager_button_new ());
 G_GNUC_END_IGNORE_DEPRECATIONS
 
   XFPM_DEBUG ("Showing tray icon");
@@ -801,42 +811,43 @@ XfpmManager *
 xfpm_manager_new (GDBusConnection *bus, const gchar *client_id)
 {
   XfpmManager *manager = NULL;
-  GError *error = NULL;
-  gchar *current_dir;
-
-  const gchar *restart_command[] =
-  {
-    "xfce4-power-manager",
-    "--restart",
-    NULL
-  };
 
   manager = g_object_new (XFPM_TYPE_MANAGER, NULL);
 
   manager->priv->session_bus = bus;
 
-  current_dir = g_get_current_dir ();
-  manager->priv->client = xfce_sm_client_get_full (XFCE_SM_CLIENT_RESTART_NORMAL,
-                                                   XFCE_SM_CLIENT_PRIORITY_DEFAULT,
-                                                   client_id,
-                                                   current_dir,
-                                                   restart_command,
-                                                   SYSCONFDIR "/xdg/autostart/" PACKAGE_NAME ".desktop");
-
-  g_free (current_dir);
-
-  manager->priv->session_managed = xfce_sm_client_connect (manager->priv->client, &error);
-
-  if ( error )
+#ifdef ENABLE_X11
+  if (WINDOWING_IS_X11 ())
   {
-    g_warning ("Unable to connect to session manager : %s", error->message);
-    g_error_free (error);
-  }
-  else
-  {
-    g_signal_connect_swapped (manager->priv->client, "quit",
-                              G_CALLBACK (xfpm_manager_quit), manager);
+    GError *error = NULL;
+    gchar *current_dir = g_get_current_dir ();
+    const gchar *restart_command[] =
+    {
+      "xfce4-power-manager",
+      "--restart",
+      NULL
+    };
+    manager->priv->client = xfce_sm_client_get_full (XFCE_SM_CLIENT_RESTART_NORMAL,
+                                                     XFCE_SM_CLIENT_PRIORITY_DEFAULT,
+                                                     client_id,
+                                                     current_dir,
+                                                     restart_command,
+                                                     SYSCONFDIR "/xdg/autostart/" PACKAGE_NAME ".desktop");
+    g_free (current_dir);
+
+    manager->priv->session_managed = xfce_sm_client_connect (manager->priv->client, &error);
+    if (error != NULL)
+    {
+      g_warning ("Unable to connect to session manager : %s", error->message);
+      g_error_free (error);
+    }
+    else
+    {
+      g_signal_connect_object (manager->priv->client, "quit",
+                               G_CALLBACK (xfpm_manager_quit), manager, G_CONNECT_SWAPPED);
+    }
   }
+#endif
 
   xfpm_manager_dbus_class_init (XFPM_MANAGER_GET_CLASS (manager));
   xfpm_manager_dbus_init (manager);
@@ -865,7 +876,8 @@ void xfpm_manager_start (XfpmManager *manager)
 
   manager->priv->monitor = xfpm_dbus_monitor_new ();
   manager->priv->inhibit = xfpm_inhibit_new ();
-  manager->priv->idle = egg_idletime_new ();
+  manager->priv->ppd = xfpm_ppd_new ();
+  manager->priv->idle = xfpm_idle_new ();
 
     /* Don't allow systemd to handle power/suspend/hibernate buttons
      * and lid-switch */
@@ -878,27 +890,30 @@ void xfpm_manager_start (XfpmManager *manager)
     g_clear_error (&error);
   }
 
-  g_signal_connect (manager->priv->idle, "alarm-expired",
-                    G_CALLBACK (xfpm_manager_alarm_timeout_cb), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" ON_AC_INACTIVITY_TIMEOUT,
-                            G_CALLBACK (xfpm_manager_set_idle_alarm_on_ac), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" ON_BATTERY_INACTIVITY_TIMEOUT,
-                            G_CALLBACK (xfpm_manager_set_idle_alarm_on_battery), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_POWER_KEY,
-                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_SUSPEND_KEY,
-                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_HIBERNATE_KEY,
-                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
-  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_LID_SWITCH,
-                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
+  if (manager->priv->idle != NULL)
+  {
+    g_signal_connect_object (manager->priv->idle, "alarm-expired",
+                             G_CALLBACK (xfpm_manager_alarm_timeout_cb), manager, 0);
+    g_signal_connect_object (manager->priv->conf, "notify::" ON_AC_INACTIVITY_TIMEOUT,
+                             G_CALLBACK (xfpm_manager_set_idle_alarm_on_ac), manager, G_CONNECT_SWAPPED);
+    g_signal_connect_object (manager->priv->conf, "notify::" ON_BATTERY_INACTIVITY_TIMEOUT,
+                             G_CALLBACK (xfpm_manager_set_idle_alarm_on_battery), manager, G_CONNECT_SWAPPED);
+    xfpm_manager_set_idle_alarm_on_ac (manager);
+    xfpm_manager_set_idle_alarm_on_battery (manager);
+  }
+  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_POWER_KEY,
+                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_SUSPEND_KEY,
+                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_HIBERNATE_KEY,
+                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_LID_SWITCH,
+                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
 
-  xfpm_manager_set_idle_alarm (manager);
-
-  g_signal_connect (manager->priv->inhibit, "has-inhibit-changed",
-                    G_CALLBACK (xfpm_manager_inhibit_changed_cb), manager);
-  g_signal_connect (manager->priv->monitor, "system-bus-connection-changed",
-                    G_CALLBACK (xfpm_manager_system_bus_connection_changed_cb), manager);
+  g_signal_connect_object (manager->priv->inhibit, "has-inhibit-changed",
+                           G_CALLBACK (xfpm_manager_inhibit_changed_cb), manager, 0);
+  g_signal_connect_object (manager->priv->monitor, "system-bus-connection-changed",
+                           G_CALLBACK (xfpm_manager_system_bus_connection_changed_cb), manager, 0);
 
   manager->priv->backlight = xfpm_backlight_new ();
 
@@ -906,26 +921,26 @@ void xfpm_manager_start (XfpmManager *manager)
 
   manager->priv->dpms = xfpm_dpms_new ();
 
-  g_signal_connect (manager->priv->button, "button_pressed",
-                    G_CALLBACK (xfpm_manager_button_pressed_cb), manager);
+  g_signal_connect_object (manager->priv->button, "button_pressed",
+                           G_CALLBACK (xfpm_manager_button_pressed_cb), manager, 0);
 
-  g_signal_connect (manager->priv->power, "lid-changed",
-                    G_CALLBACK (xfpm_manager_lid_changed_cb), manager);
+  g_signal_connect_object (manager->priv->power, "lid-changed",
+                           G_CALLBACK (xfpm_manager_lid_changed_cb), manager, 0);
 
-  g_signal_connect (manager->priv->power, "on-battery-changed",
-                    G_CALLBACK (xfpm_manager_on_battery_changed_cb), manager);
+  g_signal_connect_object (manager->priv->power, "on-battery-changed",
+                           G_CALLBACK (xfpm_manager_on_battery_changed_cb), manager, 0);
 
-  g_signal_connect_swapped (manager->priv->power, "waking-up",
-                            G_CALLBACK (xfpm_manager_reset_sleep_timer), manager);
+  g_signal_connect_object (manager->priv->power, "waking-up",
+                           G_CALLBACK (xfpm_manager_reset_sleep_timer), manager, G_CONNECT_SWAPPED);
 
-  g_signal_connect_swapped (manager->priv->power, "sleeping",
-                            G_CALLBACK (xfpm_manager_reset_sleep_timer), manager);
+  g_signal_connect_object (manager->priv->power, "sleeping",
+                           G_CALLBACK (xfpm_manager_reset_sleep_timer), manager, G_CONNECT_SWAPPED);
 
-  g_signal_connect_swapped (manager->priv->power, "ask-shutdown",
-                            G_CALLBACK (xfpm_manager_ask_shutdown), manager);
+  g_signal_connect_object (manager->priv->power, "ask-shutdown",
+                           G_CALLBACK (xfpm_manager_ask_shutdown), manager, G_CONNECT_SWAPPED);
 
-  g_signal_connect_swapped (manager->priv->power, "shutdown",
-                            G_CALLBACK (xfpm_manager_shutdown), manager);
+  g_signal_connect_object (manager->priv->power, "shutdown",
+                           G_CALLBACK (xfpm_manager_shutdown), manager, G_CONNECT_SWAPPED);
 
   xfconf_g_property_bind (xfpm_xfconf_get_channel (manager->priv->conf),
                                                    XFPM_PROPERTIES_PREFIX SHOW_TRAY_ICON_CFG,
@@ -957,7 +972,7 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
   gboolean has_power_button = FALSE;
   gboolean has_battery_button = FALSE;
   gboolean has_battery = TRUE;
-  gboolean has_lcd_brightness = TRUE;
+  gboolean has_lcd_brightness = manager->priv->backlight != NULL;
   gboolean can_shutdown = TRUE;
   gboolean auth_shutdown = TRUE;
   gboolean has_lid = FALSE;
@@ -982,8 +997,6 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
                 NULL);
 
   has_battery = xfpm_power_has_battery (manager->priv->power);
-  has_lcd_brightness = xfpm_backlight_has_hw (manager->priv->backlight);
-
   mapped_buttons = xfpm_button_get_mapped (manager->priv->button);
 
   if ( mapped_buttons & SLEEP_KEY )
@@ -1051,22 +1064,22 @@ xfpm_manager_dbus_init (XfpmManager *manager)
                                     "/org/xfce/PowerManager",
                                     NULL);
 
-  g_signal_connect_swapped (manager_dbus,
-                            "handle-quit",
-                            G_CALLBACK (xfpm_manager_dbus_quit),
-                            manager);
-  g_signal_connect_swapped (manager_dbus,
-                            "handle-restart",
-                            G_CALLBACK (xfpm_manager_dbus_restart),
-                            manager);
-  g_signal_connect_swapped (manager_dbus,
-                            "handle-get-config",
-                            G_CALLBACK (xfpm_manager_dbus_get_config),
-                            manager);
-  g_signal_connect_swapped (manager_dbus,
-                            "handle-get-info",
-                            G_CALLBACK (xfpm_manager_dbus_get_info),
-                            manager);
+  g_signal_connect_object (manager_dbus,
+                           "handle-quit",
+                           G_CALLBACK (xfpm_manager_dbus_quit),
+                           manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager_dbus,
+                           "handle-restart",
+                           G_CALLBACK (xfpm_manager_dbus_restart),
+                           manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager_dbus,
+                           "handle-get-config",
+                           G_CALLBACK (xfpm_manager_dbus_get_config),
+                           manager, G_CONNECT_SWAPPED);
+  g_signal_connect_object (manager_dbus,
+                           "handle-get-info",
+                           G_CALLBACK (xfpm_manager_dbus_get_info),
+                           manager, G_CONNECT_SWAPPED);
 }
 
 static gboolean
