@@ -34,9 +34,10 @@
 #include <errno.h>
 #endif
 
-#include <upower.h>
+#ifdef ENABLE_X11
 #include <gdk/gdkx.h>
-
+#endif
+#include <upower.h>
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
 
@@ -49,14 +50,13 @@
 #include "xfpm-errors.h"
 #include "xfpm-inhibit.h"
 #include "xfpm-polkit.h"
-#include "xfpm-network-manager.h"
 #include "xfpm-icons.h"
 #include "xfpm-common.h"
 #include "xfpm-power-common.h"
 #include "xfpm-config.h"
 #include "xfpm-debug.h"
 #include "xfpm-enum-types.h"
-#include "egg-idletime.h"
+#include "xfpm-idle.h"
 #include "xfpm-suspend.h"
 #include "xfpm-brightness.h"
 
@@ -75,7 +75,7 @@ static void xfpm_power_set_property (GObject *object,
 static void xfpm_power_change_presentation_mode (XfpmPower *power,
                                                  gboolean presentation_mode);
 
-static void xfpm_update_blank_time (XfpmPower *power);
+static void xfpm_power_toggle_screensaver (XfpmPower *power);
 
 static void xfpm_power_dbus_class_init (XfpmPowerClass * klass);
 static void xfpm_power_dbus_init (XfpmPower *power);
@@ -104,14 +104,9 @@ struct XfpmPowerPrivate
   gboolean          critical_action_done;
 
   XfpmDpms         *dpms;
-  gboolean          presentation_mode;
-  gint              on_ac_blank;
-  gint              on_battery_blank;
-  EggIdletime      *idletime;
-
-  gboolean          inhibited;
-  gboolean          screensaver_inhibited;
   XfceScreensaver  *screensaver;
+  gboolean          presentation_mode;
+  gboolean          inhibited;
 
   XfpmNotify       *notify;
 #ifdef HAVE_POLKIT
@@ -143,8 +138,6 @@ enum
   PROP_CAN_HIBERNATE,
   PROP_HAS_LID,
   PROP_PRESENTATION_MODE,
-  PROP_ON_AC_BLANK,
-  PROP_ON_BATTERY_BLANK,
   N_PROPERTIES
 };
 
@@ -172,24 +165,24 @@ xfpm_power_check_power (XfpmPower *power, gboolean on_battery)
   if (on_battery != power->priv->on_battery )
   {
     GList *list;
-    guint len, i;
+
     g_signal_emit (G_OBJECT (power), signals [ON_BATTERY_CHANGED], 0, on_battery);
 
-    xfpm_dpms_set_on_battery (power->priv->dpms, on_battery);
+    if (power->priv->dpms != NULL)
+      xfpm_dpms_set_on_battery (power->priv->dpms, on_battery);
 
       /* Dismiss critical notifications on battery state changes */
     xfpm_notify_close_critical (power->priv->notify);
 
     power->priv->on_battery = on_battery;
     list = g_hash_table_get_values (power->priv->hash);
-    len = g_list_length (list);
-    for ( i = 0; i < len; i++)
+    for (GList *lp = list; lp != NULL; lp = lp->next)
     {
-      g_object_set (G_OBJECT (g_list_nth_data (list, i)),
+      g_object_set (G_OBJECT (lp->data),
                     "ac-online", !on_battery,
                     NULL);
-      xfpm_update_blank_time (power);
     }
+    g_list_free (list);
   }
 }
 
@@ -222,15 +215,17 @@ xfpm_power_check_lid (XfpmPower *power, gboolean present, gboolean closed)
 static void
 xfpm_power_get_properties (XfpmPower *power)
 {
-  gboolean on_battery;
-  gboolean lid_is_closed;
-  gboolean lid_is_present;
+  gboolean on_battery = FALSE;
+  gboolean lid_is_closed = FALSE;
+  gboolean lid_is_present = FALSE;
+
+  if (power->priv->upower != NULL)
+    g_object_get (power->priv->upower,
+                  "on-battery", &on_battery,
+                  "lid-is-closed", &lid_is_closed,
+                  "lid-is-present", &lid_is_present,
+                  NULL);
 
-  g_object_get (power->priv->upower,
-                "on-battery", &on_battery,
-                "lid-is-closed", &lid_is_closed,
-                "lid-is-present", &lid_is_present,
-                NULL);
   xfpm_power_check_lid (power, lid_is_present, lid_is_closed);
   xfpm_power_check_power (power, on_battery);
 }
@@ -238,23 +233,6 @@ xfpm_power_get_properties (XfpmPower *power)
 static void
 xfpm_power_report_error (XfpmPower *power, const gchar *error, const gchar *icon_name)
 {
-  GtkStatusIcon *battery = NULL;
-  guint i, len;
-  GList *list;
-
-  list = g_hash_table_get_values (power->priv->hash);
-  len = g_list_length (list);
-
-  for ( i = 0; i < len; i++)
-  {
-    UpDeviceKind type;
-    battery = g_list_nth_data (list, i);
-    type = xfpm_battery_get_device_type (XFPM_BATTERY (battery));
-    if ( type == UP_DEVICE_KIND_BATTERY ||
-         type == UP_DEVICE_KIND_UPS )
-      break;
-  }
-
   xfpm_notify_show_notification (power->priv->notify,
                                  _("Power Manager"),
                                  error,
@@ -267,11 +245,8 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
 {
   GError *error = NULL;
   gboolean lock_screen;
-#ifdef WITH_NETWORK_MANAGER
-  gboolean network_manager_sleep;
-#endif
   XfpmBrightness *brightness;
-  gint32 brightness_level;
+  gint32 brightness_level = 0;
 
   if ( power->priv->inhibited && force == FALSE)
   {
@@ -295,19 +270,8 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
   g_signal_emit (G_OBJECT (power), signals [SLEEPING], 0);
     /* Get the current brightness level so we can use it after we suspend */
   brightness = xfpm_brightness_new();
-  xfpm_brightness_setup (brightness);
-  xfpm_brightness_get_level (brightness, &brightness_level);
-
-#ifdef WITH_NETWORK_MANAGER
-  g_object_get (G_OBJECT (power->priv->conf),
-                NETWORK_MANAGER_SLEEP, &network_manager_sleep,
-                NULL);
-
-  if ( network_manager_sleep )
-  {
-    xfpm_network_manager_sleep (TRUE);
-  }
-#endif
+  if (brightness != NULL)
+    xfpm_brightness_get_level (brightness, &brightness_level);
 
   g_object_get (G_OBJECT (power->priv->conf),
                 LOCK_SCREEN_ON_SLEEP, &lock_screen,
@@ -315,14 +279,7 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
 
   if ( lock_screen )
   {
-#ifdef WITH_NETWORK_MANAGER
-    if ( network_manager_sleep )
-    {
-  /* 2 seconds, to give network manager time to sleep */
-      g_usleep (2000000);
-    }
-#endif
-    if (!xfce_screensaver_lock (power->priv->screensaver))
+    if (!xfce_screensaver_lock (power->priv->screensaver) && !force)
     {
       GtkWidget *dialog;
       gboolean ret;
@@ -340,9 +297,13 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
       gtk_widget_destroy (dialog);
 
       if ( !ret || ret == GTK_RESPONSE_NO)
+      {
+        if (brightness != NULL)
+          g_object_unref (brightness);
         return;
       }
     }
+  }
 
   /* This is fun, here's the order of operations:
    * - if the Logind is running then use it
@@ -406,14 +367,11 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
     /* Check/update any changes while we slept */
   xfpm_power_get_properties (power);
     /* Restore the brightness level from before we suspended */
-  xfpm_brightness_set_level (brightness, brightness_level);
-
-#ifdef WITH_NETWORK_MANAGER
-  if ( network_manager_sleep )
+  if (brightness != NULL)
   {
-    xfpm_network_manager_sleep (FALSE);
+    xfpm_brightness_set_level (brightness, brightness_level);
+    g_object_unref (brightness);
   }
-#endif
 }
 
 static void
@@ -444,19 +402,16 @@ static XfpmBatteryCharge
 xfpm_power_get_current_charge_state (XfpmPower *power)
 {
   GList *list;
-  guint len, i;
-  gboolean power_supply;
   XfpmBatteryCharge max_charge_status = XFPM_BATTERY_CHARGE_UNKNOWN;
 
   list = g_hash_table_get_values (power->priv->hash);
-  len = g_list_length (list);
-
-  for ( i = 0; i < len; i++ )
+  for (GList *lp = list; lp != NULL; lp = lp->next)
   {
     XfpmBatteryCharge battery_charge;
     UpDeviceKind type;
+    gboolean power_supply;
 
-    g_object_get (G_OBJECT (g_list_nth_data (list, i)),
+    g_object_get (G_OBJECT (lp->data),
                     "charge-status", &battery_charge,
                     "device-type", &type,
                     "ac-online", &power_supply,
@@ -468,6 +423,7 @@ xfpm_power_get_current_charge_state (XfpmPower *power)
 
     max_charge_status = MAX (max_charge_status, battery_charge);
   }
+  g_list_free (list);
 
   return max_charge_status;
 }
@@ -590,8 +546,8 @@ xfpm_power_show_critical_action_gtk (XfpmPower *power)
     hibernate = gtk_button_new_with_label (_("Hibernate"));
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), hibernate, GTK_RESPONSE_NONE);
 
-    g_signal_connect_swapped (hibernate, "clicked",
-                              G_CALLBACK (xfpm_power_hibernate_clicked), power);
+    g_signal_connect_object (hibernate, "clicked",
+                             G_CALLBACK (xfpm_power_hibernate_clicked), power, G_CONNECT_SWAPPED);
   }
 
   xfpm_power_can_suspend (power, &can_method, &auth_method);
@@ -602,8 +558,8 @@ xfpm_power_show_critical_action_gtk (XfpmPower *power)
     suspend = gtk_button_new_with_label (_("Suspend"));
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), suspend, GTK_RESPONSE_NONE);
 
-    g_signal_connect_swapped (suspend, "clicked",
-                              G_CALLBACK (xfpm_power_suspend_clicked), power);
+    g_signal_connect_object (suspend, "clicked",
+                             G_CALLBACK (xfpm_power_suspend_clicked), power, G_CONNECT_SWAPPED);
   }
 
   if (power->priv->systemd != NULL)
@@ -622,18 +578,18 @@ xfpm_power_show_critical_action_gtk (XfpmPower *power)
     shutdown = gtk_button_new_with_label (_("Shutdown"));
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), shutdown, GTK_RESPONSE_NONE);
 
-    g_signal_connect_swapped (shutdown, "clicked",
-                              G_CALLBACK (xfpm_power_shutdown_clicked), power);
+    g_signal_connect_object (shutdown, "clicked",
+                             G_CALLBACK (xfpm_power_shutdown_clicked), power, G_CONNECT_SWAPPED);
   }
 
   cancel = gtk_button_new_with_label (_("_Cancel"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), cancel, GTK_RESPONSE_NONE);
 
-  g_signal_connect_swapped (cancel, "clicked",
-                            G_CALLBACK (xfpm_power_close_critical_dialog), power);
+  g_signal_connect_object (cancel, "clicked",
+                           G_CALLBACK (xfpm_power_close_critical_dialog), power, G_CONNECT_SWAPPED);
 
-  g_signal_connect_swapped (dialog, "destroy",
-                            G_CALLBACK (xfpm_power_close_critical_dialog), power);
+  g_signal_connect_object (dialog, "destroy",
+                           G_CALLBACK (xfpm_power_close_critical_dialog), power, G_CONNECT_SWAPPED);
   if ( power->priv->dialog )
   {
     gtk_widget_destroy (power->priv->dialog);
@@ -814,8 +770,8 @@ xfpm_power_add_device (UpDevice *device, XfpmPower *power)
                                  device_type);
     g_hash_table_insert (power->priv->hash, g_strdup (object_path), battery);
 
-    g_signal_connect (battery, "battery-charge-changed",
-                      G_CALLBACK (xfpm_power_battery_charge_changed_cb), power);
+    g_signal_connect_object (battery, "battery-charge-changed",
+                             G_CALLBACK (xfpm_power_battery_charge_changed_cb), power, 0);
   }
 }
 
@@ -853,43 +809,24 @@ xfpm_power_remove_device (XfpmPower *power, const gchar *object_path)
 static void
 xfpm_power_inhibit_changed_cb (XfpmInhibit *inhibit, gboolean is_inhibit, XfpmPower *power)
 {
-  if (power->priv->inhibited != is_inhibit)
-  {
-    power->priv->inhibited = is_inhibit;
+  /* no change, exit */
+  if (power->priv->inhibited == is_inhibit)
+    return;
 
-    XFPM_DEBUG ("is_inhibit %s, screensaver_inhibited %s, presentation_mode %s",
-                power->priv->inhibited ? "TRUE" : "FALSE",
-                power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
-                power->priv->presentation_mode ? "TRUE" : "FALSE");
+  power->priv->inhibited = is_inhibit;
 
-    xfpm_dpms_inhibit (power->priv->dpms, is_inhibit);
+  XFPM_DEBUG ("inhibited %s, presentation_mode %s",
+              power->priv->inhibited ? "TRUE" : "FALSE",
+              power->priv->presentation_mode ? "TRUE" : "FALSE");
 
-    /* If we are inhibited make sure we inhibit the screensaver too */
-    if (is_inhibit)
-    {
-      if (!power->priv->screensaver_inhibited)
-      {
-        xfce_screensaver_inhibit (power->priv->screensaver, TRUE);
-        power->priv->screensaver_inhibited = TRUE;
-      }
-    }
-    else
-    {
-      /* Or make sure we remove the screensaver inhibit */
-      if (power->priv->screensaver_inhibited && !power->priv->presentation_mode)
-      {
-        xfce_screensaver_inhibit (power->priv->screensaver, FALSE);
-        power->priv->screensaver_inhibited = FALSE;
-      }
-    }
-  }
+  /* either inhibition already occurred, or we don't want to remove it yet */
+  if (power->priv->presentation_mode)
+    return;
 
-  XFPM_DEBUG ("is_inhibit %s, screensaver_inhibited %s, presentation_mode %s",
-  power->priv->inhibited ? "TRUE" : "FALSE",
-  power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
-  power->priv->presentation_mode ? "TRUE" : "FALSE");
-
-  xfpm_update_blank_time (power);
+  xfce_screensaver_inhibit (power->priv->screensaver, is_inhibit);
+  xfpm_power_toggle_screensaver (power);
+  if (power->priv->dpms != NULL)
+    xfpm_dpms_set_inhibited (power->priv->dpms, is_inhibit);
 }
 
 static void
@@ -1046,24 +983,6 @@ xfpm_power_class_init (XfpmPowerClass *klass)
                                                          NULL, NULL,
                                                          FALSE,
                                                          XFPM_PARAM_FLAGS));
-
-  g_object_class_install_property (object_class,
-                                   PROP_ON_AC_BLANK,
-                                   g_param_spec_int (ON_AC_BLANK,
-                                                    NULL, NULL,
-                                                    0,
-                                                    G_MAXINT16,
-                                                    10,
-                                                    XFPM_PARAM_FLAGS));
-
-  g_object_class_install_property (object_class,
-                                   PROP_ON_BATTERY_BLANK,
-                                   g_param_spec_int (ON_BATTERY_BLANK,
-                                                    NULL, NULL,
-                                                    0,
-                                                    G_MAXINT16,
-                                                    10,
-                                                    XFPM_PARAM_FLAGS));
 #undef XFPM_PARAM_FLAGS
 
   xfpm_power_dbus_class_init (klass);
@@ -1089,8 +1008,6 @@ xfpm_power_init (XfpmPower *power)
   power->priv->dpms                 = xfpm_dpms_new ();
 
   power->priv->presentation_mode    = FALSE;
-  power->priv->on_ac_blank          = 15;
-  power->priv->on_battery_blank     = 10;
 
   power->priv->inhibit = xfpm_inhibit_new ();
   power->priv->notify  = xfpm_notify_new ();
@@ -1109,8 +1026,8 @@ xfpm_power_init (XfpmPower *power)
   power->priv->polkit  = xfpm_polkit_get ();
 #endif
 
-  g_signal_connect (power->priv->inhibit, "has-inhibit-changed",
-                    G_CALLBACK (xfpm_power_inhibit_changed_cb), power);
+  g_signal_connect_object (power->priv->inhibit, "has-inhibit-changed",
+                           G_CALLBACK (xfpm_power_inhibit_changed_cb), power, 0);
 
   power->priv->bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
 
@@ -1121,11 +1038,14 @@ xfpm_power_init (XfpmPower *power)
     goto out;
   }
 
-  g_signal_connect (power->priv->upower, "device-added", G_CALLBACK (xfpm_power_device_added_cb), power);
-  g_signal_connect (power->priv->upower, "device-removed", G_CALLBACK (xfpm_power_device_removed_cb), power);
-  g_signal_connect (power->priv->upower, "notify", G_CALLBACK (xfpm_power_changed_cb), power);
+  if (power->priv->upower != NULL)
+  {
+    g_signal_connect_object (power->priv->upower, "device-added", G_CALLBACK (xfpm_power_device_added_cb), power, 0);
+    g_signal_connect_object (power->priv->upower, "device-removed", G_CALLBACK (xfpm_power_device_removed_cb), power, 0);
+    g_signal_connect_object (power->priv->upower, "notify", G_CALLBACK (xfpm_power_changed_cb), power, 0);
+    xfpm_power_get_power_devices (power);
+  }
 
-  xfpm_power_get_power_devices (power);
   xfpm_power_get_properties (power);
 
 out:
@@ -1173,12 +1093,6 @@ xfpm_power_get_property (GObject *object,
     case PROP_PRESENTATION_MODE:
       g_value_set_boolean (value, power->priv->presentation_mode);
       break;
-    case PROP_ON_AC_BLANK:
-      g_value_set_int (value, power->priv->on_ac_blank);
-      break;
-    case PROP_ON_BATTERY_BLANK:
-      g_value_set_int (value, power->priv->on_battery_blank);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1192,25 +1106,12 @@ xfpm_power_set_property (GObject *object,
                          GParamSpec *pspec)
 {
   XfpmPower *power = XFPM_POWER (object);
-  gint on_ac_blank, on_battery_blank;
 
   switch (prop_id)
   {
     case PROP_PRESENTATION_MODE:
       xfpm_power_change_presentation_mode (power, g_value_get_boolean (value));
       break;
-    case PROP_ON_AC_BLANK:
-      on_ac_blank = g_value_get_int (value);
-      power->priv->on_ac_blank = on_ac_blank;
-      if (!power->priv->on_battery)
-        xfpm_update_blank_time (power);
-      break;
-    case PROP_ON_BATTERY_BLANK:
-      on_battery_blank = g_value_get_int (value);
-      power->priv->on_battery_blank = on_battery_blank;
-      if (power->priv->on_battery)
-        xfpm_update_blank_time (power);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1230,6 +1131,8 @@ xfpm_power_finalize (GObject *object)
   g_object_unref (power->priv->notify);
   g_object_unref (power->priv->conf);
   g_object_unref (power->priv->screensaver);
+  if (power->priv->upower != NULL)
+    g_object_unref (power->priv->upower);
 
   if ( power->priv->systemd != NULL )
     g_object_unref (power->priv->systemd);
@@ -1244,7 +1147,8 @@ xfpm_power_finalize (GObject *object)
   g_object_unref (power->priv->polkit);
 #endif
 
-  g_object_unref(power->priv->dpms);
+  if (power->priv->dpms != NULL)
+    g_object_unref(power->priv->dpms);
 
   G_OBJECT_CLASS (xfpm_power_parent_class)->finalize (object);
 }
@@ -1258,14 +1162,6 @@ xfpm_power_new (void)
                           XFPM_PROPERTIES_PREFIX PRESENTATION_MODE, G_TYPE_BOOLEAN,
                           G_OBJECT(power), PRESENTATION_MODE);
 
-  xfconf_g_property_bind (xfpm_xfconf_get_channel(power->priv->conf),
-                          XFPM_PROPERTIES_PREFIX ON_BATTERY_BLANK, G_TYPE_INT,
-                          G_OBJECT (power), ON_BATTERY_BLANK);
-
-  xfconf_g_property_bind (xfpm_xfconf_get_channel(power->priv->conf),
-                          XFPM_PROPERTIES_PREFIX ON_AC_BLANK, G_TYPE_INT,
-                          G_OBJECT (power), ON_AC_BLANK);
-
   return power;
 }
 
@@ -1299,20 +1195,14 @@ void xfpm_power_hibernate (XfpmPower *power, gboolean force)
 
 gboolean xfpm_power_has_battery (XfpmPower *power)
 {
-  GtkStatusIcon *battery = NULL;
-  guint i, len;
   GList *list;
-
   gboolean ret = FALSE;
 
   list = g_hash_table_get_values (power->priv->hash);
-  len = g_list_length (list);
-
-  for ( i = 0; i < len; i++)
+  for (GList *lp = list; lp != NULL; lp = lp->next)
   {
     UpDeviceKind type;
-    battery = g_list_nth_data (list, i);
-    type = xfpm_battery_get_device_type (XFPM_BATTERY (battery));
+    type = xfpm_battery_get_device_type (XFPM_BATTERY (lp->data));
     if ( type == UP_DEVICE_KIND_BATTERY ||
          type == UP_DEVICE_KIND_UPS )
     {
@@ -1320,84 +1210,64 @@ gboolean xfpm_power_has_battery (XfpmPower *power)
       break;
     }
   }
+  g_list_free (list);
 
   return ret;
 }
 
 static void
-xfpm_update_blank_time (XfpmPower *power)
+xfpm_power_toggle_screensaver (XfpmPower *power)
 {
-  int prev_timeout, prev_interval, prev_prefer_blanking, prev_allow_exposures;
-  Display* display = gdk_x11_display_get_xdisplay(gdk_display_get_default ());
-  guint screensaver_timeout;
+#ifdef ENABLE_X11
+  Display* display;
+  static int timeout = -2, interval, prefer_blanking, allow_exposures;
 
-  if (power->priv->on_battery)
-    screensaver_timeout = power->priv->on_battery_blank;
-  else
-    screensaver_timeout = power->priv->on_ac_blank;
+  if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+    return;
 
-    /* Presentation mode or inhibited disables blanking */
+  display = gdk_x11_get_default_xdisplay ();
+
+  /* Presentation mode or inhibited disables blanking */
   if (power->priv->presentation_mode || power->priv->inhibited)
-    screensaver_timeout = 0;
+  {
+    if (timeout == -2)
+      XGetScreenSaver(display, &timeout, &interval, &prefer_blanking, &allow_exposures);
 
-  screensaver_timeout = screensaver_timeout * 60;
-
-  XGetScreenSaver(display, &prev_timeout, &prev_interval, &prev_prefer_blanking, &prev_allow_exposures);
-  XFPM_DEBUG ("Prev Timeout: %d / New Timeout: %d", prev_timeout, screensaver_timeout);
-  XSetScreenSaver(display, screensaver_timeout, prev_interval, prev_prefer_blanking, prev_allow_exposures);
-  XSync (display, FALSE);
+    XFPM_DEBUG ("Disabling screensaver, timeout stored: %d", timeout);
+    XSetScreenSaver(display, 0, interval, prefer_blanking, allow_exposures);
+    XSync (display, FALSE);
+  }
+  else if (timeout != -2)
+  {
+    XFPM_DEBUG ("Enabling screensaver, timeout restored: %d", timeout);
+    XSetScreenSaver(display, timeout, interval, prefer_blanking, allow_exposures);
+    XSync (display, FALSE);
+    timeout = -2;
+  }
+#endif
 }
 
 static void
 xfpm_power_change_presentation_mode (XfpmPower *power, gboolean presentation_mode)
 {
-    /* no change, exit */
+  /* no change, exit */
   if (power->priv->presentation_mode == presentation_mode)
     return;
 
   power->priv->presentation_mode = presentation_mode;
 
-  /* presentation mode inhibits dpms */
-  xfpm_dpms_inhibit (power->priv->dpms, presentation_mode);
+  XFPM_DEBUG ("inhibited %s, presentation_mode %s",
+              power->priv->inhibited ? "TRUE" : "FALSE",
+              power->priv->presentation_mode ? "TRUE" : "FALSE");
 
-  XFPM_DEBUG ("is_inhibit %s, screensaver_inhibited %s, presentation_mode %s",
-  power->priv->inhibited ? "TRUE" : "FALSE",
-  power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
-  power->priv->presentation_mode ? "TRUE" : "FALSE");
+  /* either inhibition already occurred, or we don't want to remove it yet */
+  if (power->priv->inhibited)
+    return;
 
-  if (presentation_mode)
-  {
-  /* presentation mode inhibits the screensaver */
-    if (!power->priv->screensaver_inhibited)
-    {
-      xfce_screensaver_inhibit (power->priv->screensaver, TRUE);
-      power->priv->screensaver_inhibited = TRUE;
-    }
-  }
-  else
-  {
-    EggIdletime *idletime;
-
-    /* make sure we remove the screensaver inhibit */
-    if (power->priv->screensaver_inhibited && !power->priv->inhibited)
-    {
-      xfce_screensaver_inhibit (power->priv->screensaver, FALSE);
-      power->priv->screensaver_inhibited = FALSE;
-    }
-
-    /* reset the timers */
-    idletime = egg_idletime_new ();
-    egg_idletime_alarm_reset_all (idletime);
-
-    g_object_unref (idletime);
-  }
-
-  XFPM_DEBUG ("is_inhibit %s, screensaver_inhibited %s, presentation_mode %s",
-  power->priv->inhibited ? "TRUE" : "FALSE",
-  power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
-  power->priv->presentation_mode ? "TRUE" : "FALSE");
-
-  xfpm_update_blank_time (power);
+  xfce_screensaver_inhibit (power->priv->screensaver, presentation_mode);
+  xfpm_power_toggle_screensaver (power);
+  if (power->priv->dpms != NULL)
+    xfpm_dpms_set_inhibited (power->priv->dpms, presentation_mode);
 }
 
 gboolean
@@ -1467,54 +1337,52 @@ xfpm_power_dbus_init (XfpmPower *power)
   GDBusConnection *bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
   XfpmPowerManagement *power_dbus;
 
-  TRACE ("entering");
-
   power_dbus = xfpm_power_management_skeleton_new ();
   g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (power_dbus),
                                     bus,
                                     "/org/freedesktop/PowerManagement",
                                     NULL);
 
-  g_signal_connect_swapped (power_dbus,
-                            "handle-shutdown",
-                            G_CALLBACK (xfpm_power_dbus_shutdown),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-reboot",
-                            G_CALLBACK (xfpm_power_dbus_reboot),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-hibernate",
-                            G_CALLBACK (xfpm_power_dbus_hibernate),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-suspend",
-                            G_CALLBACK (xfpm_power_dbus_suspend),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-can-reboot",
-                            G_CALLBACK (xfpm_power_dbus_can_reboot),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-can-shutdown",
-                            G_CALLBACK (xfpm_power_dbus_can_shutdown),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-can-hibernate",
-                            G_CALLBACK (xfpm_power_dbus_can_hibernate),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-can-suspend",
-                            G_CALLBACK (xfpm_power_dbus_can_suspend),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-get-on-battery",
-                            G_CALLBACK (xfpm_power_dbus_get_on_battery),
-                            power);
-  g_signal_connect_swapped (power_dbus,
-                            "handle-get-low-battery",
-                            G_CALLBACK (xfpm_power_dbus_get_low_battery),
-                            power);
+  g_signal_connect_object (power_dbus,
+                           "handle-shutdown",
+                           G_CALLBACK (xfpm_power_dbus_shutdown),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-reboot",
+                           G_CALLBACK (xfpm_power_dbus_reboot),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-hibernate",
+                           G_CALLBACK (xfpm_power_dbus_hibernate),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-suspend",
+                           G_CALLBACK (xfpm_power_dbus_suspend),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-can-reboot",
+                           G_CALLBACK (xfpm_power_dbus_can_reboot),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-can-shutdown",
+                           G_CALLBACK (xfpm_power_dbus_can_shutdown),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-can-hibernate",
+                           G_CALLBACK (xfpm_power_dbus_can_hibernate),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-can-suspend",
+                           G_CALLBACK (xfpm_power_dbus_can_suspend),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-get-on-battery",
+                           G_CALLBACK (xfpm_power_dbus_get_on_battery),
+                           power, G_CONNECT_SWAPPED);
+  g_signal_connect_object (power_dbus,
+                           "handle-get-low-battery",
+                           G_CALLBACK (xfpm_power_dbus_get_low_battery),
+                           power, G_CONNECT_SWAPPED);
 }
 
 static gboolean xfpm_power_dbus_shutdown (XfpmPower *power,
