@@ -84,14 +84,18 @@ enum
   PROP_IDLE_SLEEP_MODE_ON_BATTERY,
   PROP_DIM_ON_AC_TIMEOUT,
   PROP_DIM_ON_BATTERY_TIMEOUT,
-#ifdef WITH_NETWORK_MANAGER
-  PROP_NETWORK_MANAGER_SLEEP,
-#endif
   PROP_LOGIND_HANDLE_POWER_KEY,
   PROP_LOGIND_HANDLE_SUSPEND_KEY,
   PROP_LOGIND_HANDLE_HIBERNATE_KEY,
   PROP_LOGIND_HANDLE_LID_SWITCH,
   PROP_HEARTBEAT_COMMAND,
+
+  PROP_PROFILE_ON_AC,
+  PROP_PROFILE_ON_BATTERY,
+
+  PROP_SHOW_PANEL_LABEL,
+  PROP_SHOW_PRESENTATION_INDICATOR,
+
   N_PROPERTIES
 };
 
@@ -189,10 +193,8 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
   if ( !g_str_has_prefix (property, XFPM_PROPERTIES_PREFIX) || strlen (property) <= strlen (XFPM_PROPERTIES_PREFIX) )
     return;
 
-  /* We handle presentation mode and blank-times in xfpm-power directly */
-  if ( g_strcmp0 (property, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE) == 0 ||
-       g_strcmp0 (property, XFPM_PROPERTIES_PREFIX ON_AC_BLANK) == 0 ||
-       g_strcmp0 (property, XFPM_PROPERTIES_PREFIX ON_BATTERY_BLANK) == 0)
+  /* We handle presentation mode in xfpm-power directly */
+  if ( g_strcmp0 (property, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE) == 0 )
     return;
 
   /* We handle brightness switch in xfpm-backlight directly */
@@ -542,6 +544,25 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                       300,
                                                       G_PARAM_READWRITE));
 
+  /**
+   * XfpmXfconf::profile-on-ac
+   **/
+  g_object_class_install_property (object_class,
+                                   PROP_PROFILE_ON_AC,
+                                   g_param_spec_string  (PROFILE_ON_AC,
+                                                         NULL, NULL,
+                                                         NULL,
+                                                         G_PARAM_READWRITE));
+  /**
+   * XfpmXfconf::profile-on-ac
+   **/
+  g_object_class_install_property (object_class,
+                                   PROP_PROFILE_ON_BATTERY,
+                                   g_param_spec_string  (PROFILE_ON_BATTERY,
+                                                         NULL, NULL,
+                                                         NULL,
+                                                         G_PARAM_READWRITE));
+
 
   /**
    * XfpmXfconf::brightness-slider-min-level
@@ -555,18 +576,6 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                      -1,
                                                      G_PARAM_READWRITE));
 
-#ifdef WITH_NETWORK_MANAGER
-  /**
-   * XfpmXfconf::network-manager-sleep
-   **/
-  g_object_class_install_property (object_class,
-                                   PROP_NETWORK_MANAGER_SLEEP,
-                                   g_param_spec_boolean (NETWORK_MANAGER_SLEEP,
-                                                         NULL, NULL,
-                                                         TRUE,
-                                                         G_PARAM_READWRITE));
-#endif
-
   /**
    * XfpmXfconf::logind-handle-power-key
    **/
@@ -616,6 +625,28 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                          NULL, NULL,
                                                          NULL,
                                                          G_PARAM_READWRITE));
+
+  /**
+   * XfpmXfconf::show-panel-label
+   **/
+  g_object_class_install_property (object_class,
+                                   PROP_SHOW_PANEL_LABEL,
+                                   g_param_spec_int (SHOW_PANEL_LABEL,
+                                                     NULL, NULL,
+                                                     PANEL_LABEL_NONE,
+                                                     PANEL_LABEL_PERCENTAGE_AND_TIME,
+                                                     PANEL_LABEL_PERCENTAGE,
+                                                     G_PARAM_READWRITE));
+
+  /**
+   * XfpmXfconf::show-presentation-indicator
+   **/
+  g_object_class_install_property (object_class,
+                                   PROP_SHOW_PRESENTATION_INDICATOR,
+                                   g_param_spec_boolean (SHOW_PRESENTATION_INDICATOR,
+                                                         NULL, NULL,
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
 }
 
 static void
@@ -638,8 +669,8 @@ xfpm_xfconf_init (XfpmXfconf *conf)
   else
   {
     conf->priv->channel = xfconf_channel_get (XFPM_CHANNEL);
-    g_signal_connect (conf->priv->channel, "property-changed",
-                      G_CALLBACK (xfpm_xfconf_property_changed_cb), conf);
+    g_signal_connect_object (conf->priv->channel, "property-changed",
+                             G_CALLBACK (xfpm_xfconf_property_changed_cb), conf, 0);
   }
   xfpm_xfconf_load (conf);
 }
